from .common import FritzBoxTools as FritzBoxTools, FritzData as FritzData
from .const import DATA_FRITZ as DATA_FRITZ, DOMAIN as DOMAIN, PLATFORMS as PLATFORMS
from .services import async_setup_services as async_setup_services, async_unload_services as async_unload_services
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PASSWORD as CONF_PASSWORD, CONF_PORT as CONF_PORT, CONF_USERNAME as CONF_USERNAME, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import ConfigEntryAuthFailed as ConfigEntryAuthFailed, ConfigEntryNotReady as ConfigEntryNotReady
from typing import Any

_LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def update_listener(hass: HomeAssistant, entry: ConfigEntry) -> None: ...



from homeassistant.const import EVENT_HOMEASSISTANT_FINAL_WRITE as EVENT_HOMEASSISTANT_FINAL_WRITE
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, CoreState as CoreState, Event as Event, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.event import async_call_later as async_call_later
from homeassistant.loader import bind_hass as bind_hass
from json import JSONEncoder
from typing import Any, Callable

STORAGE_DIR: str
_LOGGER: Any

async def async_migrator(hass, old_path, store, *, old_conf_load_func: Any | None = ..., old_conf_migrate_func: Any | None = ...): ...

class Store:
    version: Any
    key: Any
    hass: Any
    _private: Any
    _data: Any
    _unsub_delay_listener: Any
    _unsub_final_write_listener: Any
    _write_lock: Any
    _load_task: Any
    _encoder: Any
    def __init__(self, hass: HomeAssistant, version: int, key: str, private: bool = ..., *, encoder: Union[type[JSONEncoder], None] = ...) -> None: ...
    @property
    def path(self): ...
    async def async_load(self) -> Union[dict, list, None]: ...
    async def _async_load(self): ...
    async def _async_load_data(self): ...
    async def async_save(self, data: Union[dict, list]) -> None: ...
    def async_delay_save(self, data_func: Callable[[], dict], delay: float = ...) -> None: ...
    def _async_ensure_final_write_listener(self) -> None: ...
    def _async_cleanup_final_write_listener(self) -> None: ...
    def _async_cleanup_delay_listener(self) -> None: ...
    async def _async_callback_delayed_write(self, _now) -> None: ...
    async def _async_callback_final_write(self, _event: Event) -> None: ...
    async def _async_handle_write_data(self, *_args) -> None: ...
    def _write_data(self, path: str, data: dict) -> None: ...
    async def _async_migrate_func(self, old_version, old_data) -> None: ...
    async def async_remove(self) -> None: ...



from .const import ATTR_ELEMENT as ATTR_ELEMENT, ATTR_MODALITY as ATTR_MODALITY, DOMAIN as DOMAIN, ELEMENT_AIR as ELEMENT_AIR, ELEMENT_EARTH as ELEMENT_EARTH, ELEMENT_FIRE as ELEMENT_FIRE, ELEMENT_WATER as ELEMENT_WATER, MODALITY_CARDINAL as MODALITY_CARDINAL, MODALITY_FIXED as MODALITY_FIXED, MODALITY_MUTABLE as MODALITY_MUTABLE, SIGN_AQUARIUS as SIGN_AQUARIUS, SIGN_ARIES as SIGN_ARIES, SIGN_CANCER as SIGN_CANCER, SIGN_CAPRICORN as SIGN_CAPRICORN, SIGN_GEMINI as SIGN_GEMINI, SIGN_LEO as SIGN_LEO, SIGN_LIBRA as SIGN_LIBRA, SIGN_PISCES as SIGN_PISCES, SIGN_SAGITTARIUS as SIGN_SAGITTARIUS, SIGN_SCORPIO as SIGN_SCORPIO, SIGN_TAURUS as SIGN_TAURUS, SIGN_VIRGO as SIGN_VIRGO
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from homeassistant.util.dt import as_local as as_local, utcnow as utcnow
from typing import Any

ZODIAC_BY_DATE: Any
ZODIAC_ICONS: Any

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...

class ZodiacSensor(SensorEntity):
    _attrs: Any
    _state: str
    def __init__(self) -> None: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def name(self) -> str: ...
    @property
    def device_class(self) -> str: ...
    @property
    def state(self) -> str: ...
    @property
    def icon(self) -> Union[str, None]: ...
    @property
    def extra_state_attributes(self) -> dict[str, str]: ...
    async def async_update(self) -> None: ...



from . import ATTR_OPTION as ATTR_OPTION, DOMAIN as DOMAIN, SERVICE_SELECT_OPTION as SERVICE_SELECT_OPTION
from collections.abc import Iterable
from homeassistant.components.select.const import ATTR_OPTIONS as ATTR_OPTIONS
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, State as State
from typing import Any

_LOGGER: Any

async def _async_reproduce_state(hass: HomeAssistant, state: State, *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...
async def async_reproduce_states(hass: HomeAssistant, states: Iterable[State], *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...



from collections.abc import Awaitable, Generator, Iterable
from homeassistant import core as core, loader as loader, requirements as requirements
from homeassistant.config import async_notify_setup_error as async_notify_setup_error
from homeassistant.const import EVENT_COMPONENT_LOADED as EVENT_COMPONENT_LOADED, EVENT_HOMEASSISTANT_START as EVENT_HOMEASSISTANT_START, PLATFORM_FORMAT as PLATFORM_FORMAT
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.util import ensure_unique_string as ensure_unique_string
from types import ModuleType
from typing import Any, Callable

_LOGGER: Any
ATTR_COMPONENT: str
BASE_PLATFORMS: Any
DATA_SETUP_DONE: str
DATA_SETUP_STARTED: str
DATA_SETUP_TIME: str
DATA_SETUP: str
DATA_DEPS_REQS: str
SLOW_SETUP_WARNING: int
SLOW_SETUP_MAX_WAIT: int

def async_set_domains_to_be_loaded(hass: core.HomeAssistant, domains: set[str]) -> None: ...
def setup_component(hass: core.HomeAssistant, domain: str, config: ConfigType) -> bool: ...
async def async_setup_component(hass: core.HomeAssistant, domain: str, config: ConfigType) -> bool: ...
async def _async_process_dependencies(hass: core.HomeAssistant, config: ConfigType, integration: loader.Integration) -> bool: ...
async def _async_setup_component(hass: core.HomeAssistant, domain: str, config: ConfigType) -> bool: ...
async def async_prepare_setup_platform(hass: core.HomeAssistant, hass_config: ConfigType, domain: str, platform_name: str) -> Union[ModuleType, None]: ...
async def async_process_deps_reqs(hass: core.HomeAssistant, config: ConfigType, integration: loader.Integration) -> None: ...
def async_when_setup(hass: core.HomeAssistant, component: str, when_setup_cb: Callable[[core.HomeAssistant, str], Awaitable[None]]) -> None: ...
def async_when_setup_or_start(hass: core.HomeAssistant, component: str, when_setup_cb: Callable[[core.HomeAssistant, str], Awaitable[None]]) -> None: ...
def _async_when_setup(hass: core.HomeAssistant, component: str, when_setup_cb: Callable[[core.HomeAssistant, str], Awaitable[None]], start_event: bool) -> None: ...
def async_get_loaded_integrations(hass: core.HomeAssistant) -> set: ...
def async_start_setup(hass: core.HomeAssistant, components: Iterable) -> Generator: ...



from . import FritzBoxEntity as FritzBoxEntity
from .const import CONF_COORDINATOR as CONF_COORDINATOR
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity, DEVICE_CLASS_WINDOW as DEVICE_CLASS_WINDOW
from homeassistant.components.sensor import ATTR_STATE_CLASS as ATTR_STATE_CLASS
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_DEVICE_CLASS as ATTR_DEVICE_CLASS, ATTR_ENTITY_ID as ATTR_ENTITY_ID, ATTR_NAME as ATTR_NAME, ATTR_UNIT_OF_MEASUREMENT as ATTR_UNIT_OF_MEASUREMENT
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class FritzboxBinarySensor(FritzBoxEntity, BinarySensorEntity):
    @property
    def is_on(self) -> bool: ...



from .const import KEY_AUTHENTICATED as KEY_AUTHENTICATED, KEY_HASS as KEY_HASS
from aiohttp import web
from aiohttp.typedefs import LooseHeaders as LooseHeaders
from aiohttp.web_urldispatcher import AbstractRoute as AbstractRoute
from collections.abc import Awaitable, Callable as Callable
from homeassistant import exceptions as exceptions
from homeassistant.const import CONTENT_TYPE_JSON as CONTENT_TYPE_JSON, HTTP_OK as HTTP_OK, HTTP_SERVICE_UNAVAILABLE as HTTP_SERVICE_UNAVAILABLE
from homeassistant.core import Context as Context, is_callback as is_callback
from homeassistant.helpers.json import JSONEncoder as JSONEncoder
from typing import Any

_LOGGER: Any

class HomeAssistantView:
    url: Union[str, None]
    extra_urls: list[str]
    requires_auth: bool
    cors_allowed: bool
    @staticmethod
    def context(request: web.Request) -> Context: ...
    @staticmethod
    def json(result: Any, status_code: int = ..., headers: Union[LooseHeaders, None] = ...) -> web.Response: ...
    def json_message(self, message: str, status_code: int = ..., message_code: Union[str, None] = ..., headers: Union[LooseHeaders, None] = ...) -> web.Response: ...
    def register(self, app: web.Application, router: web.UrlDispatcher) -> None: ...

def request_handler_factory(view: HomeAssistantView, handler: Callable) -> Callable[[web.Request], Awaitable[web.StreamResponse]]: ...



from .types import CategoryType as CategoryType, PolicyType as PolicyType

def merge_policies(policies: list[PolicyType]) -> PolicyType: ...
def _merge_policies(sources: list[CategoryType]) -> CategoryType: ...



from .const import DATA_NEST as DATA_NEST, DOMAIN as DOMAIN
from homeassistant.components.camera import Camera as Camera, PLATFORM_SCHEMA as PLATFORM_SCHEMA, SUPPORT_ON_OFF as SUPPORT_ON_OFF
from homeassistant.util.dt import utcnow as utcnow
from typing import Any

_LOGGER: Any
NEST_BRAND: str

def setup_platform(hass, config, add_entities, discovery_info: Any | None = ...) -> None: ...
async def async_setup_legacy_entry(hass, entry, async_add_entities) -> None: ...

class NestCamera(Camera):
    structure: Any
    device: Any
    _location: Any
    _name: Any
    _online: Any
    _is_streaming: Any
    _is_video_history_enabled: bool
    _time_between_snapshots: Any
    _last_image: Any
    _next_snapshot_at: Any
    def __init__(self, structure, device) -> None: ...
    @property
    def name(self): ...
    @property
    def unique_id(self): ...
    @property
    def device_info(self): ...
    @property
    def should_poll(self): ...
    @property
    def is_recording(self): ...
    @property
    def brand(self): ...
    @property
    def supported_features(self): ...
    @property
    def is_on(self): ...
    def turn_off(self) -> None: ...
    def turn_on(self) -> None: ...
    def update(self) -> None: ...
    def _ready_for_snapshot(self, now): ...
    def camera_image(self): ...



import homeassistant.core
from enum import Enum
from typing import Any, Dict, Mapping, Optional, Tuple, Union

GPSType = Tuple[float, float]
ConfigType = Dict[str, Any]
ContextType = homeassistant.core.Context
DiscoveryInfoType = Dict[str, Any]
EventType = homeassistant.core.Event
ServiceDataType = Dict[str, Any]
StateType = Union[None, str, int, float]
TemplateVarsType = Optional[Mapping[str, Any]]
QueryType = Any

class UndefinedType(Enum):
    _singleton: int

UNDEFINED: Any
HomeAssistantType = homeassistant.core.HomeAssistant
ServiceCallType = homeassistant.core.ServiceCall



from .const import ATTR_LAST_KNX_UPDATE as ATTR_LAST_KNX_UPDATE, ATTR_SOURCE as ATTR_SOURCE, DOMAIN as DOMAIN
from .knx_entity import KnxEntity as KnxEntity
from .schema import SensorSchema as SensorSchema
from homeassistant.components.sensor import DEVICE_CLASSES as DEVICE_CLASSES, SensorEntity as SensorEntity
from homeassistant.const import CONF_NAME as CONF_NAME, CONF_TYPE as CONF_TYPE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType, StateType as StateType
from homeassistant.util import dt as dt
from typing import Any
from xknx import XKNX as XKNX
from xknx.devices import Sensor as XknxSensor

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...
def _create_sensor(xknx: XKNX, config: ConfigType) -> XknxSensor: ...

class KNXSensor(KnxEntity, SensorEntity):
    _device: XknxSensor
    _attr_device_class: Any
    _attr_force_update: Any
    _attr_unique_id: Any
    _attr_unit_of_measurement: Any
    def __init__(self, xknx: XKNX, config: ConfigType) -> None: ...
    @property
    def state(self) -> StateType: ...
    @property
    def extra_state_attributes(self) -> Union[dict[str, Any], None]: ...



from . import DOMAIN as DOMAIN
from .const import CONDITION_ARMED_AWAY as CONDITION_ARMED_AWAY, CONDITION_ARMED_CUSTOM_BYPASS as CONDITION_ARMED_CUSTOM_BYPASS, CONDITION_ARMED_HOME as CONDITION_ARMED_HOME, CONDITION_ARMED_NIGHT as CONDITION_ARMED_NIGHT, CONDITION_ARMED_VACATION as CONDITION_ARMED_VACATION, CONDITION_DISARMED as CONDITION_DISARMED, CONDITION_TRIGGERED as CONDITION_TRIGGERED
from homeassistant.components.alarm_control_panel.const import SUPPORT_ALARM_ARM_AWAY as SUPPORT_ALARM_ARM_AWAY, SUPPORT_ALARM_ARM_CUSTOM_BYPASS as SUPPORT_ALARM_ARM_CUSTOM_BYPASS, SUPPORT_ALARM_ARM_HOME as SUPPORT_ALARM_ARM_HOME, SUPPORT_ALARM_ARM_NIGHT as SUPPORT_ALARM_ARM_NIGHT, SUPPORT_ALARM_ARM_VACATION as SUPPORT_ALARM_ARM_VACATION
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, CONF_CONDITION as CONF_CONDITION, CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_TYPE as CONF_TYPE, STATE_ALARM_ARMED_AWAY as STATE_ALARM_ARMED_AWAY, STATE_ALARM_ARMED_CUSTOM_BYPASS as STATE_ALARM_ARMED_CUSTOM_BYPASS, STATE_ALARM_ARMED_HOME as STATE_ALARM_ARMED_HOME, STATE_ALARM_ARMED_NIGHT as STATE_ALARM_ARMED_NIGHT, STATE_ALARM_ARMED_VACATION as STATE_ALARM_ARMED_VACATION, STATE_ALARM_DISARMED as STATE_ALARM_DISARMED, STATE_ALARM_TRIGGERED as STATE_ALARM_TRIGGERED
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers import condition as condition, entity_registry as entity_registry
from homeassistant.helpers.config_validation import DEVICE_CONDITION_BASE_SCHEMA as DEVICE_CONDITION_BASE_SCHEMA
from homeassistant.helpers.entity import get_supported_features as get_supported_features
from homeassistant.helpers.typing import ConfigType as ConfigType, TemplateVarsType as TemplateVarsType
from typing import Any, Final

CONDITION_TYPES: Final[set[str]]
CONDITION_SCHEMA: Final[Any]

async def async_get_conditions(hass: HomeAssistant, device_id: str) -> list[dict[str, str]]: ...
def async_condition_from_config(config: ConfigType, config_validation: bool) -> condition.ConditionCheckerType: ...



from typing import Any

DOMAIN: str
LOGGER: Any
DATA_COORDINATOR: str
SENSOR_BATTERY: str
SENSOR_DOOR: str
SENSOR_GARAGE_DOOR: str
SENSOR_LEAK: str
SENSOR_MISSING: str
SENSOR_SAFE: str
SENSOR_SLIDING: str
SENSOR_SMOKE_CO: str
SENSOR_TEMPERATURE: str
SENSOR_WINDOW_HINGED_HORIZONTAL: str
SENSOR_WINDOW_HINGED_VERTICAL: str



from . import EsphomeEntity as EsphomeEntity, esphome_state_property as esphome_state_property, platform_async_setup_entry as platform_async_setup_entry
from aioesphomeapi import SelectInfo, SelectState
from homeassistant.components.select import SelectEntity as SelectEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

ICON_SCHEMA: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class EsphomeSelect(EsphomeEntity[SelectInfo, SelectState], SelectEntity):
    @property
    def icon(self) -> Union[str, None]: ...
    @property
    def options(self) -> list[str]: ...
    def current_option(self) -> Union[str, None]: ...
    async def async_select_option(self, option: str) -> None: ...



from .const import DATA_ELGATO_CLIENT as DATA_ELGATO_CLIENT, DOMAIN as DOMAIN, SERVICE_IDENTIFY as SERVICE_IDENTIFY
from elgato import Elgato as Elgato, Info as Info, Settings as Settings, State as State
from homeassistant.components.light import ATTR_BRIGHTNESS as ATTR_BRIGHTNESS, ATTR_COLOR_TEMP as ATTR_COLOR_TEMP, ATTR_HS_COLOR as ATTR_HS_COLOR, COLOR_MODE_COLOR_TEMP as COLOR_MODE_COLOR_TEMP, COLOR_MODE_HS as COLOR_MODE_HS, LightEntity as LightEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_IDENTIFIERS as ATTR_IDENTIFIERS, ATTR_MANUFACTURER as ATTR_MANUFACTURER, ATTR_MODEL as ATTR_MODEL, ATTR_NAME as ATTR_NAME, ATTR_SW_VERSION as ATTR_SW_VERSION
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback, async_get_current_platform as async_get_current_platform
from typing import Any

_LOGGER: Any
PARALLEL_UPDATES: int
SCAN_INTERVAL: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ElgatoLight(LightEntity):
    _info: Any
    _settings: Any
    _state: Any
    elgato: Any
    _attr_max_mireds: Any
    _attr_min_mireds: Any
    _attr_name: Any
    _attr_supported_color_modes: Any
    _attr_unique_id: Any
    def __init__(self, elgato: Elgato, info: Info, settings: Settings) -> None: ...
    @property
    def available(self) -> bool: ...
    @property
    def brightness(self) -> Union[int, None]: ...
    @property
    def color_temp(self) -> Union[int, None]: ...
    @property
    def color_mode(self) -> Union[str, None]: ...
    @property
    def hs_color(self) -> Union[tuple[float, float], None]: ...
    @property
    def is_on(self) -> bool: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_update(self) -> None: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    async def async_identify(self) -> None: ...



from .const import DEFAULT_HOST as DEFAULT_HOST, DEFAULT_USERNAME as DEFAULT_USERNAME, DOMAIN as DOMAIN
from homeassistant.components.ssdp import ATTR_SSDP_LOCATION as ATTR_SSDP_LOCATION, ATTR_UPNP_FRIENDLY_NAME as ATTR_UPNP_FRIENDLY_NAME, ATTR_UPNP_UDN as ATTR_UPNP_UDN
from homeassistant.config_entries import ConfigEntry as ConfigEntry, ConfigFlow as ConfigFlow
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PASSWORD as CONF_PASSWORD, CONF_USERNAME as CONF_USERNAME
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.typing import DiscoveryInfoType as DiscoveryInfoType
from typing import Any

DATA_SCHEMA_USER: Any
DATA_SCHEMA_CONFIRM: Any
RESULT_INVALID_AUTH: str
RESULT_NO_DEVICES_FOUND: str
RESULT_NOT_SUPPORTED: str
RESULT_SUCCESS: str

class FritzboxConfigFlow(ConfigFlow):
    VERSION: int
    _entry: Any
    _host: Any
    _name: Any
    _password: Any
    _username: Any
    def __init__(self) -> None: ...
    def _get_entry(self, name: str) -> FlowResult: ...
    async def _update_entry(self) -> None: ...
    def _try_connect(self) -> str: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_ssdp(self, discovery_info: DiscoveryInfoType) -> FlowResult: ...
    async def async_step_confirm(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_reauth(self, data: dict[str, str]) -> FlowResult: ...
    async def async_step_reauth_confirm(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



from .const import CAMERA_IMAGE_TIMEOUT as CAMERA_IMAGE_TIMEOUT, CAMERA_STREAM_SOURCE_TIMEOUT as CAMERA_STREAM_SOURCE_TIMEOUT, CONF_DURATION as CONF_DURATION, CONF_LOOKBACK as CONF_LOOKBACK, DATA_CAMERA_PREFS as DATA_CAMERA_PREFS, DOMAIN as DOMAIN, SERVICE_RECORD as SERVICE_RECORD
from .prefs import CameraPreferences as CameraPreferences
from aiohttp import web
from collections.abc import Awaitable
from homeassistant.components import websocket_api as websocket_api
from homeassistant.components.http import HomeAssistantView as HomeAssistantView, KEY_AUTHENTICATED as KEY_AUTHENTICATED
from homeassistant.components.media_player.const import ATTR_MEDIA_CONTENT_ID as ATTR_MEDIA_CONTENT_ID, ATTR_MEDIA_CONTENT_TYPE as ATTR_MEDIA_CONTENT_TYPE, ATTR_MEDIA_EXTRA as ATTR_MEDIA_EXTRA, SERVICE_PLAY_MEDIA as SERVICE_PLAY_MEDIA
from homeassistant.components.stream import Stream as Stream, create_stream as create_stream
from homeassistant.components.stream.const import FORMAT_CONTENT_TYPE as FORMAT_CONTENT_TYPE, OUTPUT_FORMATS as OUTPUT_FORMATS
from homeassistant.components.websocket_api import ActiveConnection as ActiveConnection
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, CONF_FILENAME as CONF_FILENAME, CONTENT_TYPE_MULTIPART as CONTENT_TYPE_MULTIPART, EVENT_HOMEASSISTANT_START as EVENT_HOMEASSISTANT_START, SERVICE_TURN_OFF as SERVICE_TURN_OFF, SERVICE_TURN_ON as SERVICE_TURN_ON
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, ServiceCall as ServiceCall, callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE
from homeassistant.helpers.entity import Entity as Entity, EntityDescription as EntityDescription, entity_sources as entity_sources
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.helpers.network import get_url as get_url
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.loader import bind_hass as bind_hass
from typing import Any, Callable, Final

_LOGGER: Any
SERVICE_ENABLE_MOTION: Final[str]
SERVICE_DISABLE_MOTION: Final[str]
SERVICE_SNAPSHOT: Final[str]
SERVICE_PLAY_STREAM: Final[str]
SCAN_INTERVAL: Final[Any]
ENTITY_ID_FORMAT: Final[Any]
ATTR_FILENAME: Final[str]
ATTR_MEDIA_PLAYER: Final[str]
ATTR_FORMAT: Final[str]
STATE_RECORDING: Final[str]
STATE_STREAMING: Final[str]
STATE_IDLE: Final[str]
SUPPORT_ON_OFF: Final[int]
SUPPORT_STREAM: Final[int]
DEFAULT_CONTENT_TYPE: Final[str]
ENTITY_IMAGE_URL: Final[str]
TOKEN_CHANGE_INTERVAL: Final[Any]
_RND: Final[Any]
MIN_STREAM_INTERVAL: Final[float]
CAMERA_SERVICE_SNAPSHOT: Final[Any]
CAMERA_SERVICE_PLAY_STREAM: Final[Any]
CAMERA_SERVICE_RECORD: Final[Any]
WS_TYPE_CAMERA_THUMBNAIL: Final[str]
SCHEMA_WS_CAMERA_THUMBNAIL: Final[Any]

class CameraEntityDescription(EntityDescription): ...

class Image:
    content_type: str
    content: bytes
    def __init__(self, content_type, content) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

async def async_request_stream(hass: HomeAssistant, entity_id: str, fmt: str) -> str: ...
async def async_get_image(hass: HomeAssistant, entity_id: str, timeout: int = ...) -> Image: ...
async def async_get_stream_source(hass: HomeAssistant, entity_id: str) -> Union[str, None]: ...
async def async_get_mjpeg_stream(hass: HomeAssistant, request: web.Request, entity_id: str) -> Union[web.StreamResponse, None]: ...
async def async_get_still_stream(request: web.Request, image_cb: Callable[[], Awaitable[Union[bytes, None]]], content_type: str, interval: float) -> web.StreamResponse: ...
def _get_camera_from_entity_id(hass: HomeAssistant, entity_id: str) -> Camera: ...
async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class Camera(Entity):
    is_streaming: bool
    stream: Any
    stream_options: Any
    content_type: Any
    access_tokens: Any
    def __init__(self) -> None: ...
    @property
    def should_poll(self) -> bool: ...
    @property
    def entity_picture(self) -> str: ...
    @property
    def supported_features(self) -> int: ...
    @property
    def is_recording(self) -> bool: ...
    @property
    def brand(self) -> Union[str, None]: ...
    @property
    def motion_detection_enabled(self) -> bool: ...
    @property
    def model(self) -> Union[str, None]: ...
    @property
    def frame_interval(self) -> float: ...
    async def create_stream(self) -> Union[Stream, None]: ...
    async def stream_source(self) -> Union[str, None]: ...
    def camera_image(self) -> Union[bytes, None]: ...
    async def async_camera_image(self) -> Union[bytes, None]: ...
    async def handle_async_still_stream(self, request: web.Request, interval: float) -> web.StreamResponse: ...
    async def handle_async_mjpeg_stream(self, request: web.Request) -> Union[web.StreamResponse, None]: ...
    @property
    def state(self) -> str: ...
    @property
    def is_on(self) -> bool: ...
    def turn_off(self) -> None: ...
    async def async_turn_off(self) -> None: ...
    def turn_on(self) -> None: ...
    async def async_turn_on(self) -> None: ...
    def enable_motion_detection(self) -> None: ...
    async def async_enable_motion_detection(self) -> None: ...
    def disable_motion_detection(self) -> None: ...
    async def async_disable_motion_detection(self) -> None: ...
    @property
    def state_attributes(self) -> dict[str, Union[str, None]]: ...
    def async_update_token(self) -> None: ...

class CameraView(HomeAssistantView):
    requires_auth: bool
    component: Any
    def __init__(self, component: EntityComponent) -> None: ...
    async def get(self, request: web.Request, entity_id: str) -> web.StreamResponse: ...
    async def handle(self, request: web.Request, camera: Camera) -> web.StreamResponse: ...

class CameraImageView(CameraView):
    url: str
    name: str
    async def handle(self, request: web.Request, camera: Camera) -> web.Response: ...

class CameraMjpegStream(CameraView):
    url: str
    name: str
    async def handle(self, request: web.Request, camera: Camera) -> web.StreamResponse: ...

async def websocket_camera_thumbnail(hass: HomeAssistant, connection: ActiveConnection, msg: dict) -> None: ...
async def ws_camera_stream(hass: HomeAssistant, connection: ActiveConnection, msg: dict) -> None: ...
async def websocket_get_prefs(hass: HomeAssistant, connection: ActiveConnection, msg: dict) -> None: ...
async def websocket_update_prefs(hass: HomeAssistant, connection: ActiveConnection, msg: dict) -> None: ...
async def async_handle_snapshot_service(camera: Camera, service_call: ServiceCall) -> None: ...
async def async_handle_play_stream_service(camera: Camera, service_call: ServiceCall) -> None: ...
async def _async_stream_endpoint_url(hass: HomeAssistant, camera: Camera, fmt: str) -> str: ...
async def async_handle_record_service(camera: Camera, service_call: ServiceCall) -> None: ...



from .integration_platform import async_process_integration_platforms as async_process_integration_platforms
from homeassistant.const import STATE_UNAVAILABLE as STATE_UNAVAILABLE, STATE_UNKNOWN as STATE_UNKNOWN
from homeassistant.core import HomeAssistant as HomeAssistant, State as State, callback as callback
from types import MappingProxyType
from typing import Any, Callable, Optional, Union

PLATFORM: str
DATA_FUNCTIONS: str
CheckTypeFunc = Callable[[HomeAssistant, str, Union[dict, MappingProxyType], str, Union[dict, MappingProxyType]], Optional[bool]]
ExtraCheckTypeFunc = Callable[[HomeAssistant, str, Union[dict, MappingProxyType], Any, str, Union[dict, MappingProxyType], Any], Optional[bool]]

async def create_checker(hass: HomeAssistant, _domain: str, extra_significant_check: Union[ExtraCheckTypeFunc, None] = ...) -> SignificantlyChangedChecker: ...
async def _initialize(hass: HomeAssistant) -> None: ...
def either_one_none(val1: Union[Any, None], val2: Union[Any, None]) -> bool: ...
def check_numeric_changed(val1: Union[int, float, None], val2: Union[int, float, None], change: Union[int, float]) -> bool: ...

class SignificantlyChangedChecker:
    hass: Any
    last_approved_entities: Any
    extra_significant_check: Any
    def __init__(self, hass: HomeAssistant, extra_significant_check: Union[ExtraCheckTypeFunc, None] = ...) -> None: ...
    def async_is_significant_change(self, new_state: State, *, extra_arg: Union[Any, None] = ...) -> bool: ...



from collections.abc import Coroutine
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from typing import Any, TypedDict

class SSDPFlow(TypedDict):
    domain: str
    context: dict[str, Any]
    data: dict

class FlowDispatcher:
    hass: Any
    pending_flows: Any
    started: bool
    def __init__(self, hass: HomeAssistant) -> None: ...
    def async_start(self, *_: Any) -> None: ...
    def _async_process_pending_flows(self) -> None: ...
    def create(self, flow: SSDPFlow) -> None: ...
    def _init_flow(self, flow: SSDPFlow) -> Coroutine[None, None, FlowResult]: ...



from collections.abc import Iterable
from homeassistant.const import SERVICE_RELOAD as SERVICE_RELOAD
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers import config_per_platform as config_per_platform
from homeassistant.helpers.entity_platform import EntityPlatform as EntityPlatform, async_get_platforms as async_get_platforms
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.loader import async_get_integration as async_get_integration
from homeassistant.setup import async_setup_component as async_setup_component
from typing import Any

_LOGGER: Any

async def async_reload_integration_platforms(hass: HomeAssistant, integration_name: str, integration_platforms: Iterable) -> None: ...
async def _resetup_platform(hass: HomeAssistant, integration_name: str, integration_platform: str, unprocessed_conf: ConfigType) -> None: ...
async def _async_setup_platform(hass: HomeAssistant, integration_name: str, integration_platform: str, platform_configs: list[dict]) -> None: ...
async def _async_reconfig_platform(platform: EntityPlatform, platform_configs: list[dict]) -> None: ...
async def async_integration_yaml_config(hass: HomeAssistant, integration_name: str) -> Union[ConfigType, None]: ...
def async_get_platform_without_config_entry(hass: HomeAssistant, integration_name: str, integration_platform_name: str) -> Union[EntityPlatform, None]: ...
async def async_setup_reload_service(hass: HomeAssistant, domain: str, platforms: Iterable) -> None: ...
def setup_reload_service(hass: HomeAssistant, domain: str, platforms: Iterable) -> None: ...



from .const import SENSOR_TYPES as SENSOR_TYPES, SENSOR_TYPE_COUNT as SENSOR_TYPE_COUNT, SENSOR_TYPE_SENSED as SENSOR_TYPE_SENSED, SWITCH_TYPE_LATCH as SWITCH_TYPE_LATCH, SWITCH_TYPE_PIO as SWITCH_TYPE_PIO
from .model import DeviceComponentDescription as DeviceComponentDescription
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo, Entity as Entity
from homeassistant.helpers.typing import StateType as StateType
from pyownet import protocol
from typing import Any

_LOGGER: Any

class OneWireBaseEntity(Entity):
    _name: Any
    _device_file: Any
    _entity_type: Any
    _device_class: Any
    _unit_of_measurement: Any
    _device_info: Any
    _state: Any
    _value_raw: Any
    _default_disabled: Any
    _unique_id: Any
    def __init__(self, name: str, device_file: str, entity_type: str, entity_name: str, device_info: DeviceInfo, default_disabled: bool, unique_id: str) -> None: ...
    @property
    def name(self) -> Union[str, None]: ...
    @property
    def device_class(self) -> Union[str, None]: ...
    @property
    def extra_state_attributes(self) -> Union[dict[str, Any], None]: ...
    @property
    def unique_id(self) -> Union[str, None]: ...
    @property
    def device_info(self) -> Union[DeviceInfo, None]: ...
    @property
    def entity_registry_enabled_default(self) -> bool: ...

class OneWireProxyEntity(OneWireBaseEntity):
    _owproxy: Any
    def __init__(self, device_id: str, device_name: str, device_info: DeviceInfo, entity_path: str, entity_specs: DeviceComponentDescription, owproxy: protocol._Proxy) -> None: ...
    def _read_value_ownet(self) -> str: ...
    def _write_value_ownet(self, value: bytes) -> None: ...
    _value_raw: Any
    _state: Any
    def update(self) -> None: ...



from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import SERVICE_TOGGLE as SERVICE_TOGGLE, SERVICE_TURN_OFF as SERVICE_TURN_OFF, SERVICE_TURN_ON as SERVICE_TURN_ON, STATE_ON as STATE_ON
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE
from homeassistant.helpers.entity import ToggleEntity as ToggleEntity, ToggleEntityDescription as ToggleEntityDescription
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.loader import bind_hass as bind_hass
from typing import Any

DOMAIN: str
SCAN_INTERVAL: Any
ENTITY_ID_FORMAT: Any
ATTR_TODAY_ENERGY_KWH: str
ATTR_CURRENT_POWER_W: str
MIN_TIME_BETWEEN_SCANS: Any
PROP_TO_ATTR: Any
DEVICE_CLASS_OUTLET: str
DEVICE_CLASS_SWITCH: str
DEVICE_CLASSES: Any
DEVICE_CLASSES_SCHEMA: Any
_LOGGER: Any

def is_on(hass: HomeAssistant, entity_id: str) -> bool: ...
async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class SwitchEntityDescription(ToggleEntityDescription): ...

class SwitchEntity(ToggleEntity):
    entity_description: SwitchEntityDescription
    _attr_current_power_w: Union[float, None]
    _attr_today_energy_kwh: Union[float, None]
    @property
    def current_power_w(self) -> Union[float, None]: ...
    @property
    def today_energy_kwh(self) -> Union[float, None]: ...
    @property
    def state_attributes(self) -> Union[dict[str, Any], None]: ...

class SwitchDevice(SwitchEntity):
    def __init_subclass__(cls, **kwargs: Any) -> None: ...



import datetime
from . import Stream as Stream
from .const import ATTR_STREAMS as ATTR_STREAMS, DOMAIN as DOMAIN, TARGET_SEGMENT_DURATION as TARGET_SEGMENT_DURATION
from aiohttp import web
from collections import deque
from homeassistant.components.http.view import HomeAssistantView as HomeAssistantView
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.event import async_call_later as async_call_later
from homeassistant.util.decorator import Registry as Registry
from typing import Any

PROVIDERS: Any

class Part:
    duration: float
    has_keyframe: bool
    data: bytes
    def __init__(self, duration, has_keyframe, data) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class Segment:
    sequence: int
    init: bytes
    duration: float
    stream_id: int
    parts: list[Part]
    start_time: datetime.datetime
    @property
    def complete(self) -> bool: ...
    def get_bytes_without_init(self) -> bytes: ...
    def __init__(self, sequence, init, duration, stream_id, parts, start_time) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

class IdleTimer:
    _hass: Any
    _timeout: Any
    _callback: Any
    _unsub: Any
    idle: bool
    def __init__(self, hass: HomeAssistant, timeout: int, idle_callback: CALLBACK_TYPE) -> None: ...
    def start(self) -> None: ...
    def awake(self) -> None: ...
    def clear(self) -> None: ...
    def fire(self, _now: datetime.datetime) -> None: ...

class StreamOutput:
    _hass: Any
    idle_timer: Any
    _event: Any
    _segments: Any
    def __init__(self, hass: HomeAssistant, idle_timer: IdleTimer, deque_maxlen: Union[int, None] = ...) -> None: ...
    @property
    def name(self) -> Union[str, None]: ...
    @property
    def idle(self) -> bool: ...
    @property
    def last_sequence(self) -> int: ...
    @property
    def sequences(self) -> list[int]: ...
    @property
    def last_segment(self) -> Union[Segment, None]: ...
    @property
    def target_duration(self) -> float: ...
    def get_segment(self, sequence: int) -> Union[Segment, None]: ...
    def get_segments(self) -> deque[Segment]: ...
    async def recv(self) -> bool: ...
    def put(self, segment: Segment) -> None: ...
    def _async_put(self, segment: Segment) -> None: ...
    def cleanup(self) -> None: ...

class StreamView(HomeAssistantView):
    requires_auth: bool
    platform: Any
    async def get(self, request: web.Request, token: str, sequence: str = ...) -> web.StreamResponse: ...
    async def handle(self, request: web.Request, stream: Stream, sequence: str) -> web.StreamResponse: ...



from collections.abc import Sequence
from homeassistant import auth as auth
from homeassistant.const import ATTR_ASSUMED_STATE as ATTR_ASSUMED_STATE, ATTR_FRIENDLY_NAME as ATTR_FRIENDLY_NAME, ATTR_HIDDEN as ATTR_HIDDEN, CONF_ALLOWLIST_EXTERNAL_DIRS as CONF_ALLOWLIST_EXTERNAL_DIRS, CONF_ALLOWLIST_EXTERNAL_URLS as CONF_ALLOWLIST_EXTERNAL_URLS, CONF_AUTH_MFA_MODULES as CONF_AUTH_MFA_MODULES, CONF_AUTH_PROVIDERS as CONF_AUTH_PROVIDERS, CONF_CURRENCY as CONF_CURRENCY, CONF_CUSTOMIZE as CONF_CUSTOMIZE, CONF_CUSTOMIZE_DOMAIN as CONF_CUSTOMIZE_DOMAIN, CONF_CUSTOMIZE_GLOB as CONF_CUSTOMIZE_GLOB, CONF_ELEVATION as CONF_ELEVATION, CONF_EXTERNAL_URL as CONF_EXTERNAL_URL, CONF_ID as CONF_ID, CONF_INTERNAL_URL as CONF_INTERNAL_URL, CONF_LATITUDE as CONF_LATITUDE, CONF_LEGACY_TEMPLATES as CONF_LEGACY_TEMPLATES, CONF_LONGITUDE as CONF_LONGITUDE, CONF_MEDIA_DIRS as CONF_MEDIA_DIRS, CONF_NAME as CONF_NAME, CONF_PACKAGES as CONF_PACKAGES, CONF_TEMPERATURE_UNIT as CONF_TEMPERATURE_UNIT, CONF_TIME_ZONE as CONF_TIME_ZONE, CONF_TYPE as CONF_TYPE, CONF_UNIT_SYSTEM as CONF_UNIT_SYSTEM, CONF_UNIT_SYSTEM_IMPERIAL as CONF_UNIT_SYSTEM_IMPERIAL, LEGACY_CONF_WHITELIST_EXTERNAL_DIRS as LEGACY_CONF_WHITELIST_EXTERNAL_DIRS, TEMP_CELSIUS as TEMP_CELSIUS, __version__ as __version__
from homeassistant.core import HomeAssistant as HomeAssistant, SOURCE_YAML as SOURCE_YAML, callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers import config_per_platform as config_per_platform, extract_domain_configs as extract_domain_configs
from homeassistant.helpers.entity_values import EntityValues as EntityValues
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.loader import Integration as Integration, IntegrationNotFound as IntegrationNotFound
from homeassistant.requirements import RequirementsNotFound as RequirementsNotFound, async_get_integration_with_requirements as async_get_integration_with_requirements
from homeassistant.util.package import is_docker_env as is_docker_env
from homeassistant.util.unit_system import IMPERIAL_SYSTEM as IMPERIAL_SYSTEM, METRIC_SYSTEM as METRIC_SYSTEM
from homeassistant.util.yaml import SECRET_YAML as SECRET_YAML, Secrets as Secrets, load_yaml as load_yaml
from types import ModuleType
from typing import Any, Callable

_LOGGER: Any
DATA_PERSISTENT_ERRORS: str
RE_YAML_ERROR: Any
RE_ASCII: Any
YAML_CONFIG_FILE: str
VERSION_FILE: str
CONFIG_DIR_NAME: str
DATA_CUSTOMIZE: str
GROUP_CONFIG_PATH: str
AUTOMATION_CONFIG_PATH: str
SCRIPT_CONFIG_PATH: str
SCENE_CONFIG_PATH: str
LOAD_EXCEPTIONS: Any
INTEGRATION_LOAD_EXCEPTIONS: Any
DEFAULT_CONFIG: Any
DEFAULT_SECRETS: str
TTS_PRE_92: str
TTS_92: str

def _no_duplicate_auth_provider(configs: Sequence[dict[str, Any]]) -> Sequence[dict[str, Any]]: ...
def _no_duplicate_auth_mfa_module(configs: Sequence[dict[str, Any]]) -> Sequence[dict[str, Any]]: ...

PACKAGES_CONFIG_SCHEMA: Any
CUSTOMIZE_DICT_SCHEMA: Any
CUSTOMIZE_CONFIG_SCHEMA: Any
CORE_CONFIG_SCHEMA: Any

def get_default_config_dir() -> str: ...
async def async_ensure_config_exists(hass: HomeAssistant) -> bool: ...
async def async_create_default_config(hass: HomeAssistant) -> bool: ...
def _write_default_config(config_dir: str) -> bool: ...
async def async_hass_config_yaml(hass: HomeAssistant) -> dict: ...
def load_yaml_config_file(config_path: str, secrets: Union[Secrets, None] = ...) -> dict[Any, Any]: ...
def process_ha_config_upgrade(hass: HomeAssistant) -> None: ...
def async_log_exception(ex: Exception, domain: str, config: dict, hass: HomeAssistant, link: Union[str, None] = ...) -> None: ...
def _format_config_error(ex: Exception, domain: str, config: dict, link: Union[str, None] = ...) -> tuple[str, bool]: ...
async def async_process_ha_core_config(hass: HomeAssistant, config: dict) -> None: ...
def _log_pkg_error(package: str, component: str, config: dict, message: str) -> None: ...
def _identify_config_schema(module: ModuleType) -> Union[str, None]: ...
def _recursive_merge(conf: dict[str, Any], package: dict[str, Any]) -> Union[bool, str]: ...
async def merge_packages_config(hass: HomeAssistant, config: dict, packages: dict[str, Any], _log_pkg_error: Callable = ...) -> dict: ...
async def async_process_component_config(hass: HomeAssistant, config: ConfigType, integration: Integration) -> Union[ConfigType, None]: ...
def config_without_domain(config: dict, domain: str) -> dict: ...
async def async_check_ha_config_file(hass: HomeAssistant) -> Union[str, None]: ...
def async_notify_setup_error(hass: HomeAssistant, component: str, display_link: Union[str, None] = ...) -> None: ...



from . import DOMAIN as DOMAIN
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, CONF_CONDITION as CONF_CONDITION, CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_TYPE as CONF_TYPE, STATE_IDLE as STATE_IDLE, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON, STATE_PAUSED as STATE_PAUSED, STATE_PLAYING as STATE_PLAYING
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers import condition as condition, entity_registry as entity_registry
from homeassistant.helpers.config_validation import DEVICE_CONDITION_BASE_SCHEMA as DEVICE_CONDITION_BASE_SCHEMA
from homeassistant.helpers.typing import ConfigType as ConfigType, TemplateVarsType as TemplateVarsType
from typing import Any

CONDITION_TYPES: Any
CONDITION_SCHEMA: Any

async def async_get_conditions(hass: HomeAssistant, device_id: str) -> list[dict[str, str]]: ...
def async_condition_from_config(config: ConfigType, config_validation: bool) -> condition.ConditionCheckerType: ...



from homeassistant.components.sensor import SensorEntityDescription as SensorEntityDescription

class DSMRSensorEntityDescription(SensorEntityDescription):
    dsmr_versions: Union[set[str], None]
    is_gas: bool



from . import LcnEntity as LcnEntity
from .const import CONF_DOMAIN_DATA as CONF_DOMAIN_DATA, LED_PORTS as LED_PORTS, S0_INPUTS as S0_INPUTS, SETPOINTS as SETPOINTS, THRESHOLDS as THRESHOLDS, VARIABLES as VARIABLES
from .helpers import DeviceConnectionType as DeviceConnectionType, InputType as InputType, get_device_connection as get_device_connection
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_ADDRESS as CONF_ADDRESS, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITIES as CONF_ENTITIES, CONF_SOURCE as CONF_SOURCE, CONF_UNIT_OF_MEASUREMENT as CONF_UNIT_OF_MEASUREMENT
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

def create_lcn_sensor_entity(hass: HomeAssistant, entity_config: ConfigType, config_entry: ConfigEntry) -> LcnEntity: ...
async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class LcnVariableSensor(LcnEntity, SensorEntity):
    variable: Any
    unit: Any
    _value: Any
    def __init__(self, config: ConfigType, entry_id: str, device_connection: DeviceConnectionType) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def unit_of_measurement(self) -> str: ...
    def input_received(self, input_obj: InputType) -> None: ...

class LcnLedLogicSensor(LcnEntity, SensorEntity):
    source: Any
    _value: Any
    def __init__(self, config: ConfigType, entry_id: str, device_connection: DeviceConnectionType) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    @property
    def state(self) -> Union[str, None]: ...
    def input_received(self, input_obj: InputType) -> None: ...



from . import NestSensorDevice as NestSensorDevice
from .const import DATA_NEST as DATA_NEST, DATA_NEST_CONFIG as DATA_NEST_CONFIG
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity, DEVICE_CLASS_CONNECTIVITY as DEVICE_CLASS_CONNECTIVITY, DEVICE_CLASS_MOTION as DEVICE_CLASS_MOTION, DEVICE_CLASS_OCCUPANCY as DEVICE_CLASS_OCCUPANCY, DEVICE_CLASS_SOUND as DEVICE_CLASS_SOUND
from homeassistant.const import CONF_BINARY_SENSORS as CONF_BINARY_SENSORS, CONF_MONITORED_CONDITIONS as CONF_MONITORED_CONDITIONS
from typing import Any

_LOGGER: Any
BINARY_TYPES: Any
CLIMATE_BINARY_TYPES: Any
CAMERA_BINARY_TYPES: Any
STRUCTURE_BINARY_TYPES: Any
STRUCTURE_BINARY_STATE_MAP: Any
_BINARY_TYPES_DEPRECATED: Any
_VALID_BINARY_SENSOR_TYPES: Any

def setup_platform(hass, config, add_entities, discovery_info: Any | None = ...) -> None: ...
async def async_setup_legacy_entry(hass, entry, async_add_entities) -> None: ...

class NestBinarySensor(NestSensorDevice, BinarySensorEntity):
    @property
    def is_on(self): ...
    @property
    def device_class(self): ...
    _state: Any
    def update(self) -> None: ...

class NestActivityZoneSensor(NestBinarySensor):
    zone: Any
    _name: Any
    def __init__(self, structure, device, zone) -> None: ...
    @property
    def unique_id(self): ...
    @property
    def device_class(self): ...
    _state: Any
    def update(self) -> None: ...



from .const import NOTIFICATION_ID as NOTIFICATION_ID, NOTIFICATION_TITLE as NOTIFICATION_TITLE, STATES_MAP as STATES_MAP, SUPPORTED_FEATURES as SUPPORTED_FEATURES
from .model import DoorDevice as DoorDevice
from aladdin_connect import AladdinConnectClient
from homeassistant.components.cover import CoverEntity as CoverEntity, DEVICE_CLASS_GARAGE as DEVICE_CLASS_GARAGE
from homeassistant.const import CONF_PASSWORD as CONF_PASSWORD, CONF_USERNAME as CONF_USERNAME, STATE_CLOSED as STATE_CLOSED, STATE_CLOSING as STATE_CLOSING, STATE_OPENING as STATE_OPENING
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from typing import Any, Final

_LOGGER: Final[Any]
PLATFORM_SCHEMA: Final[Any]

def setup_platform(hass: HomeAssistant, config: ConfigType, add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...

class AladdinDevice(CoverEntity):
    _attr_device_class: Any
    _attr_supported_features: Any
    _acc: Any
    _device_id: Any
    _number: Any
    _attr_name: Any
    _attr_unique_id: Any
    def __init__(self, acc: AladdinConnectClient, device: DoorDevice) -> None: ...
    def close_cover(self, **kwargs: Any) -> None: ...
    def open_cover(self, **kwargs: Any) -> None: ...
    _attr_is_opening: Any
    _attr_is_closing: Any
    _attr_is_closed: Any
    def update(self) -> None: ...



import datetime as dt
from .frame import report as report
from collections.abc import Iterable
from homeassistant.components.sun import STATE_ABOVE_HORIZON as STATE_ABOVE_HORIZON, STATE_BELOW_HORIZON as STATE_BELOW_HORIZON
from homeassistant.const import STATE_CLOSED as STATE_CLOSED, STATE_HOME as STATE_HOME, STATE_LOCKED as STATE_LOCKED, STATE_NOT_HOME as STATE_NOT_HOME, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON, STATE_OPEN as STATE_OPEN, STATE_UNKNOWN as STATE_UNKNOWN, STATE_UNLOCKED as STATE_UNLOCKED
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, State as State
from homeassistant.loader import IntegrationNotFound as IntegrationNotFound, async_get_integration as async_get_integration, bind_hass as bind_hass
from types import TracebackType
from typing import Any

_LOGGER: Any

class AsyncTrackStates:
    hass: Any
    states: Any
    def __init__(self, hass: HomeAssistant) -> None: ...
    now: Any
    def __enter__(self) -> list[State]: ...
    def __exit__(self, exc_type: Union[type[BaseException], None], exc_value: Union[BaseException, None], traceback: Union[TracebackType, None]) -> None: ...

def get_changed_since(states: Iterable[State], utc_point_in_time: dt.datetime) -> list[State]: ...
async def async_reproduce_state(hass: HomeAssistant, states: Union[State, Iterable[State]], *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...
def state_as_number(state: State) -> float: ...



from typing import Any, Final

ATTR_CID: Final[str]
ATTR_MAC: Final[str]
ATTR_MANUFACTURER: Final[str]
ATTR_MODEL: Final[str]
CONF_IGNORED_SOURCES: Final[str]
BRAVIA_CONFIG_FILE: Final[str]
CLIENTID_PREFIX: Final[str]
DEFAULT_NAME: Final[Any]
DOMAIN: Final[str]
NICKNAME: Final[str]



from .const import DATA_CLIENT as DATA_CLIENT, DOMAIN as DOMAIN
from .discovery import ZwaveDiscoveryInfo as ZwaveDiscoveryInfo
from .entity import ZWaveBaseEntity as ZWaveBaseEntity
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity, DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_DOOR as DEVICE_CLASS_DOOR, DEVICE_CLASS_GAS as DEVICE_CLASS_GAS, DEVICE_CLASS_HEAT as DEVICE_CLASS_HEAT, DEVICE_CLASS_LOCK as DEVICE_CLASS_LOCK, DEVICE_CLASS_MOISTURE as DEVICE_CLASS_MOISTURE, DEVICE_CLASS_MOTION as DEVICE_CLASS_MOTION, DEVICE_CLASS_PROBLEM as DEVICE_CLASS_PROBLEM, DEVICE_CLASS_SAFETY as DEVICE_CLASS_SAFETY, DEVICE_CLASS_SMOKE as DEVICE_CLASS_SMOKE, DEVICE_CLASS_SOUND as DEVICE_CLASS_SOUND
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any, TypedDict
from zwave_js_server.client import Client as ZwaveClient

LOGGER: Any
NOTIFICATION_SMOKE_ALARM: int
NOTIFICATION_CARBON_MONOOXIDE: int
NOTIFICATION_CARBON_DIOXIDE: int
NOTIFICATION_HEAT: int
NOTIFICATION_WATER: int
NOTIFICATION_ACCESS_CONTROL: int
NOTIFICATION_HOME_SECURITY: int
NOTIFICATION_POWER_MANAGEMENT: int
NOTIFICATION_SYSTEM: int
NOTIFICATION_EMERGENCY: int
NOTIFICATION_CLOCK: int
NOTIFICATION_APPLIANCE: int
NOTIFICATION_HOME_HEALTH: int
NOTIFICATION_SIREN: int
NOTIFICATION_WATER_VALVE: int
NOTIFICATION_WEATHER: int
NOTIFICATION_IRRIGATION: int
NOTIFICATION_GAS: int

class NotificationSensorMapping(TypedDict):
    type: int
    states: list[str]
    device_class: str
    enabled: bool

NOTIFICATION_SENSOR_MAPPINGS: list[NotificationSensorMapping]
PROPERTY_DOOR_STATUS: str

class PropertySensorMapping(TypedDict):
    property_name: str
    on_states: list[str]
    device_class: str
    enabled: bool

PROPERTY_SENSOR_MAPPINGS: list[PropertySensorMapping]

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ZWaveBooleanBinarySensor(ZWaveBaseEntity, BinarySensorEntity):
    _attr_name: Any
    _attr_device_class: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def is_on(self) -> Union[bool, None]: ...

class ZWaveNotificationBinarySensor(ZWaveBaseEntity, BinarySensorEntity):
    state_key: Any
    _mapping_info: Any
    _attr_name: Any
    _attr_device_class: Any
    _attr_unique_id: Any
    _attr_entity_registry_enabled_default: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo, state_key: str) -> None: ...
    @property
    def is_on(self) -> Union[bool, None]: ...
    def _get_sensor_mapping(self) -> NotificationSensorMapping: ...

class ZWavePropertyBinarySensor(ZWaveBaseEntity, BinarySensorEntity):
    _mapping_info: Any
    _attr_name: Any
    _attr_device_class: Any
    _attr_entity_registry_enabled_default: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def is_on(self) -> Union[bool, None]: ...
    def _get_sensor_mapping(self) -> PropertySensorMapping: ...



from .const import DATA_SUBSCRIBER as DATA_SUBSCRIBER, DOMAIN as DOMAIN
from .device_info import NestDeviceInfo as NestDeviceInfo
from google_nest_sdm.device import Device as Device
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, PERCENTAGE as PERCENTAGE, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.exceptions import PlatformNotReady as PlatformNotReady
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

_LOGGER: Any
DEVICE_TYPE_MAP: Any

async def async_setup_sdm_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class SensorBase(SensorEntity):
    _device: Any
    _device_info: Any
    def __init__(self, device: Device) -> None: ...
    @property
    def should_poll(self) -> bool: ...
    @property
    def unique_id(self) -> Union[str, None]: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    async def async_added_to_hass(self) -> None: ...

class TemperatureSensor(SensorBase):
    @property
    def name(self) -> str: ...
    @property
    def state(self) -> float: ...
    @property
    def unit_of_measurement(self) -> str: ...
    @property
    def device_class(self) -> str: ...

class HumiditySensor(SensorBase):
    @property
    def unique_id(self) -> Union[str, None]: ...
    @property
    def name(self) -> str: ...
    @property
    def state(self) -> float: ...
    @property
    def unit_of_measurement(self) -> str: ...
    @property
    def device_class(self) -> str: ...



from typing import Dict, TypedDict

KrakenResponse = Dict[str, Dict[str, float]]

class SensorType(TypedDict):
    name: str
    enabled_by_default: bool

DEFAULT_SCAN_INTERVAL: int
DEFAULT_TRACKED_ASSET_PAIR: str
DISPATCH_CONFIG_UPDATED: str
CONF_TRACKED_ASSET_PAIRS: str
DOMAIN: str
SENSOR_TYPES: list[SensorType]



from typing import Final

DOMAIN: Final[str]
DATA_CAMERA_PREFS: Final[str]
PREF_PRELOAD_STREAM: Final[str]
SERVICE_RECORD: Final[str]
CONF_LOOKBACK: Final[str]
CONF_DURATION: Final[str]
CAMERA_STREAM_SOURCE_TIMEOUT: Final[int]
CAMERA_IMAGE_TIMEOUT: Final[int]



from . import ATTR_AWAY_MODE as ATTR_AWAY_MODE, ATTR_OPERATION_MODE as ATTR_OPERATION_MODE, ATTR_TEMPERATURE as ATTR_TEMPERATURE, DOMAIN as DOMAIN, SERVICE_SET_AWAY_MODE as SERVICE_SET_AWAY_MODE, SERVICE_SET_OPERATION_MODE as SERVICE_SET_OPERATION_MODE, SERVICE_SET_TEMPERATURE as SERVICE_SET_TEMPERATURE, STATE_ECO as STATE_ECO, STATE_ELECTRIC as STATE_ELECTRIC, STATE_GAS as STATE_GAS, STATE_HEAT_PUMP as STATE_HEAT_PUMP, STATE_HIGH_DEMAND as STATE_HIGH_DEMAND, STATE_PERFORMANCE as STATE_PERFORMANCE
from collections.abc import Iterable
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, SERVICE_TURN_OFF as SERVICE_TURN_OFF, SERVICE_TURN_ON as SERVICE_TURN_ON, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, State as State
from typing import Any

_LOGGER: Any
VALID_STATES: Any

async def _async_reproduce_state(hass: HomeAssistant, state: State, *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...
async def async_reproduce_states(hass: HomeAssistant, states: Iterable[State], *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...



from .const import CONF_FFMPEG_ARGUMENTS as CONF_FFMPEG_ARGUMENTS, DEFAULT_FFMPEG_ARGUMENTS as DEFAULT_FFMPEG_ARGUMENTS, DEFAULT_TIMEOUT as DEFAULT_TIMEOUT, DOMAIN as DOMAIN
from homeassistant.config_entries import ConfigEntry as ConfigEntry, ConfigFlow as ConfigFlow, OptionsFlow as OptionsFlow
from homeassistant.const import CONF_PASSWORD as CONF_PASSWORD, CONF_TIMEOUT as CONF_TIMEOUT, CONF_USERNAME as CONF_USERNAME
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any, Final

_LOGGER: Final[Any]

def validate_input(hass: HomeAssistant, data: dict[str, Any]) -> bool: ...

class CanaryConfigFlow(ConfigFlow):
    VERSION: int
    @staticmethod
    def async_get_options_flow(config_entry: ConfigEntry) -> OptionsFlow: ...
    async def async_step_import(self, user_input: Union[ConfigType, None] = ...) -> FlowResult: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...

class CanaryOptionsFlowHandler(OptionsFlow):
    config_entry: Any
    def __init__(self, config_entry: ConfigEntry) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



from . import DOMAIN as DOMAIN
from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA as DEVICE_TRIGGER_BASE_SCHEMA
from homeassistant.components.device_automation.exceptions import InvalidDeviceAutomationConfig as InvalidDeviceAutomationConfig
from homeassistant.const import CONF_ABOVE as CONF_ABOVE, CONF_BELOW as CONF_BELOW, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_FOR as CONF_FOR, CONF_TYPE as CONF_TYPE, DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_CO as DEVICE_CLASS_CO, DEVICE_CLASS_CO2 as DEVICE_CLASS_CO2, DEVICE_CLASS_CURRENT as DEVICE_CLASS_CURRENT, DEVICE_CLASS_ENERGY as DEVICE_CLASS_ENERGY, DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_ILLUMINANCE as DEVICE_CLASS_ILLUMINANCE, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, DEVICE_CLASS_POWER_FACTOR as DEVICE_CLASS_POWER_FACTOR, DEVICE_CLASS_PRESSURE as DEVICE_CLASS_PRESSURE, DEVICE_CLASS_SIGNAL_STRENGTH as DEVICE_CLASS_SIGNAL_STRENGTH, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, DEVICE_CLASS_VOLTAGE as DEVICE_CLASS_VOLTAGE
from homeassistant.core import HomeAssistantError as HomeAssistantError
from homeassistant.helpers.entity import get_device_class as get_device_class, get_unit_of_measurement as get_unit_of_measurement
from homeassistant.helpers.entity_registry import async_entries_for_device as async_entries_for_device
from typing import Any

DEVICE_CLASS_NONE: str
CONF_BATTERY_LEVEL: str
CONF_CO: str
CONF_CO2: str
CONF_CURRENT: str
CONF_ENERGY: str
CONF_HUMIDITY: str
CONF_ILLUMINANCE: str
CONF_POWER: str
CONF_POWER_FACTOR: str
CONF_PRESSURE: str
CONF_SIGNAL_STRENGTH: str
CONF_TEMPERATURE: str
CONF_VOLTAGE: str
CONF_VALUE: str
ENTITY_TRIGGERS: Any
TRIGGER_SCHEMA: Any

async def async_attach_trigger(hass, config, action, automation_info): ...
async def async_get_triggers(hass, device_id): ...
async def async_get_trigger_capabilities(hass, config): ...



from . import EsphomeEntity as EsphomeEntity, EsphomeEnumMapper as EsphomeEnumMapper, esphome_state_property as esphome_state_property, platform_async_setup_entry as platform_async_setup_entry
from aioesphomeapi import LightColorMode, LightInfo, LightState
from homeassistant.components.light import ATTR_BRIGHTNESS as ATTR_BRIGHTNESS, ATTR_COLOR_TEMP as ATTR_COLOR_TEMP, ATTR_EFFECT as ATTR_EFFECT, ATTR_FLASH as ATTR_FLASH, ATTR_RGBWW_COLOR as ATTR_RGBWW_COLOR, ATTR_RGBW_COLOR as ATTR_RGBW_COLOR, ATTR_RGB_COLOR as ATTR_RGB_COLOR, ATTR_TRANSITION as ATTR_TRANSITION, ATTR_WHITE as ATTR_WHITE, COLOR_MODE_BRIGHTNESS as COLOR_MODE_BRIGHTNESS, COLOR_MODE_COLOR_TEMP as COLOR_MODE_COLOR_TEMP, COLOR_MODE_ONOFF as COLOR_MODE_ONOFF, COLOR_MODE_RGB as COLOR_MODE_RGB, COLOR_MODE_RGBW as COLOR_MODE_RGBW, COLOR_MODE_RGBWW as COLOR_MODE_RGBWW, COLOR_MODE_UNKNOWN as COLOR_MODE_UNKNOWN, COLOR_MODE_WHITE as COLOR_MODE_WHITE, FLASH_LONG as FLASH_LONG, FLASH_SHORT as FLASH_SHORT, LightEntity as LightEntity, SUPPORT_EFFECT as SUPPORT_EFFECT, SUPPORT_FLASH as SUPPORT_FLASH, SUPPORT_TRANSITION as SUPPORT_TRANSITION
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

FLASH_LENGTHS: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

_COLOR_MODES: EsphomeEnumMapper[LightColorMode, str]

class EsphomeLight(EsphomeEntity[LightInfo, LightState], LightEntity):
    @property
    def _supports_color_mode(self) -> bool: ...
    def is_on(self) -> Union[bool, None]: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    def brightness(self) -> Union[int, None]: ...
    def color_mode(self) -> Union[str, None]: ...
    def rgb_color(self) -> Union[tuple[int, int, int], None]: ...
    def rgbw_color(self) -> Union[tuple[int, int, int, int], None]: ...
    def rgbww_color(self) -> Union[tuple[int, int, int, int, int], None]: ...
    def color_temp(self) -> Union[float, None]: ...
    def effect(self) -> Union[str, None]: ...
    @property
    def _native_supported_color_modes(self) -> list[LightColorMode]: ...
    @property
    def supported_features(self) -> int: ...
    @property
    def supported_color_modes(self) -> Union[set[str], None]: ...
    @property
    def effect_list(self) -> list[str]: ...
    @property
    def min_mireds(self) -> float: ...
    @property
    def max_mireds(self) -> float: ...



from homeassistant.const import HTTP_OK as HTTP_OK
from multidict import MultiDict
from typing import Any

class MockStreamReader:
    _content: Any
    def __init__(self, content: bytes) -> None: ...
    async def read(self, byte_count: int = ...) -> bytes: ...

class MockRequest:
    mock_source: Union[str, None]
    method: Any
    url: Any
    status: Any
    headers: Any
    query_string: Any
    _content: Any
    def __init__(self, content: bytes, mock_source: str, method: str = ..., status: int = ..., headers: Union[dict[str, str], None] = ..., query_string: Union[str, None] = ..., url: str = ...) -> None: ...
    @property
    def query(self) -> MultiDict[str]: ...
    @property
    def _text(self) -> str: ...
    @property
    def content(self) -> MockStreamReader: ...
    async def json(self) -> Any: ...
    async def post(self) -> MultiDict[str]: ...
    async def text(self) -> str: ...



from ..helpers.frame import MissingIntegrationFrame as MissingIntegrationFrame, get_integration_frame as get_integration_frame
from typing import Any, Callable

def deprecated_substitute(substitute_name: str) -> Callable[..., Callable]: ...
def get_deprecated(config: dict[str, Any], new_name: str, old_name: str, default: Union[Any, None] = ...) -> Union[Any, None]: ...
def deprecated_class(replacement: str) -> Any: ...
def deprecated_function(replacement: str) -> Callable[..., Callable]: ...
def _print_deprecation_warning(obj: Any, replacement: str, description: str) -> None: ...



from .const import RECORDER_CONTAINER_FORMAT as RECORDER_CONTAINER_FORMAT, RECORDER_PROVIDER as RECORDER_PROVIDER, SEGMENT_CONTAINER_FORMAT as SEGMENT_CONTAINER_FORMAT
from .core import IdleTimer as IdleTimer, PROVIDERS as PROVIDERS, Segment as Segment, StreamOutput as StreamOutput
from av.container import OutputContainer as OutputContainer
from collections import deque
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from typing import Any

_LOGGER: Any

def async_setup_recorder(hass: HomeAssistant) -> None: ...
def recorder_save_worker(file_out: str, segments: deque[Segment]) -> None: ...

class RecorderOutput(StreamOutput):
    video_path: Any
    def __init__(self, hass: HomeAssistant, idle_timer: IdleTimer) -> None: ...
    @property
    def name(self) -> str: ...
    def prepend(self, segments: list[Segment]) -> None: ...
    def cleanup(self) -> None: ...



from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import PRECISION_TENTHS as PRECISION_TENTHS, PRECISION_WHOLE as PRECISION_WHOLE, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE
from homeassistant.helpers.entity import Entity as Entity, EntityDescription as EntityDescription
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from typing import Any, Final, TypedDict

_LOGGER: Any
ATTR_CONDITION_CLASS: str
ATTR_CONDITION_CLEAR_NIGHT: str
ATTR_CONDITION_CLOUDY: str
ATTR_CONDITION_EXCEPTIONAL: str
ATTR_CONDITION_FOG: str
ATTR_CONDITION_HAIL: str
ATTR_CONDITION_LIGHTNING: str
ATTR_CONDITION_LIGHTNING_RAINY: str
ATTR_CONDITION_PARTLYCLOUDY: str
ATTR_CONDITION_POURING: str
ATTR_CONDITION_RAINY: str
ATTR_CONDITION_SNOWY: str
ATTR_CONDITION_SNOWY_RAINY: str
ATTR_CONDITION_SUNNY: str
ATTR_CONDITION_WINDY: str
ATTR_CONDITION_WINDY_VARIANT: str
ATTR_FORECAST: str
ATTR_FORECAST_CONDITION: Final[str]
ATTR_FORECAST_PRECIPITATION: Final[str]
ATTR_FORECAST_PRECIPITATION_PROBABILITY: Final[str]
ATTR_FORECAST_PRESSURE: Final[str]
ATTR_FORECAST_TEMP: Final[str]
ATTR_FORECAST_TEMP_LOW: Final[str]
ATTR_FORECAST_TIME: Final[str]
ATTR_FORECAST_WIND_BEARING: Final[str]
ATTR_FORECAST_WIND_SPEED: Final[str]
ATTR_WEATHER_ATTRIBUTION: str
ATTR_WEATHER_HUMIDITY: str
ATTR_WEATHER_OZONE: str
ATTR_WEATHER_PRESSURE: str
ATTR_WEATHER_TEMPERATURE: str
ATTR_WEATHER_VISIBILITY: str
ATTR_WEATHER_WIND_BEARING: str
ATTR_WEATHER_WIND_SPEED: str
DOMAIN: str
ENTITY_ID_FORMAT: Any
SCAN_INTERVAL: Any

class Forecast(TypedDict):
    condition: Union[str, None]
    datetime: str
    precipitation_probability: Union[int, None]
    precipitation: Union[float, None]
    pressure: Union[float, None]
    temperature: Union[float, None]
    templow: Union[float, None]
    wind_bearing: Union[float, str, None]
    wind_speed: Union[float, None]

async def async_setup(hass, config): ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class WeatherEntityDescription(EntityDescription): ...

class WeatherEntity(Entity):
    entity_description: WeatherEntityDescription
    _attr_attribution: Union[str, None]
    _attr_condition: Union[str, None]
    _attr_forecast: Union[list[Forecast], None]
    _attr_humidity: Union[float, None]
    _attr_ozone: Union[float, None]
    _attr_precision: float
    _attr_pressure: Union[float, None]
    _attr_state: None
    _attr_temperature_unit: str
    _attr_temperature: Union[float, None]
    _attr_visibility: Union[float, None]
    _attr_wind_bearing: Union[float, str, None]
    _attr_wind_speed: Union[float, None]
    @property
    def temperature(self) -> Union[float, None]: ...
    @property
    def temperature_unit(self) -> str: ...
    @property
    def pressure(self) -> Union[float, None]: ...
    @property
    def humidity(self) -> Union[float, None]: ...
    @property
    def wind_speed(self) -> Union[float, None]: ...
    @property
    def wind_bearing(self) -> Union[float, str, None]: ...
    @property
    def ozone(self) -> Union[float, None]: ...
    @property
    def attribution(self) -> Union[str, None]: ...
    @property
    def visibility(self) -> Union[float, None]: ...
    @property
    def forecast(self) -> Union[list[Forecast], None]: ...
    @property
    def precision(self) -> float: ...
    @property
    def state_attributes(self): ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def condition(self) -> Union[str, None]: ...



from . import SimpliSafeBaseSensor as SimpliSafeBaseSensor
from .const import DATA_CLIENT as DATA_CLIENT, DOMAIN as DOMAIN, LOGGER as LOGGER
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class SimplisafeFreezeSensor(SimpliSafeBaseSensor, SensorEntity):
    _attr_device_class: Any
    _attr_unit_of_measurement: Any
    _attr_state: Any
    def async_update_from_rest_api(self) -> None: ...



from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import STATE_OFF as STATE_OFF, STATE_ON as STATE_ON
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE
from homeassistant.helpers.entity import Entity as Entity, EntityDescription as EntityDescription
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.helpers.typing import ConfigType as ConfigType, StateType as StateType
from typing import Any

_LOGGER: Any
DOMAIN: str
SCAN_INTERVAL: Any
ENTITY_ID_FORMAT: Any
DEVICE_CLASS_BATTERY: str
DEVICE_CLASS_BATTERY_CHARGING: str
DEVICE_CLASS_COLD: str
DEVICE_CLASS_CONNECTIVITY: str
DEVICE_CLASS_DOOR: str
DEVICE_CLASS_GARAGE_DOOR: str
DEVICE_CLASS_GAS: str
DEVICE_CLASS_HEAT: str
DEVICE_CLASS_LIGHT: str
DEVICE_CLASS_LOCK: str
DEVICE_CLASS_MOISTURE: str
DEVICE_CLASS_MOTION: str
DEVICE_CLASS_MOVING: str
DEVICE_CLASS_OCCUPANCY: str
DEVICE_CLASS_OPENING: str
DEVICE_CLASS_PLUG: str
DEVICE_CLASS_POWER: str
DEVICE_CLASS_PRESENCE: str
DEVICE_CLASS_PROBLEM: str
DEVICE_CLASS_SAFETY: str
DEVICE_CLASS_SMOKE: str
DEVICE_CLASS_SOUND: str
DEVICE_CLASS_VIBRATION: str
DEVICE_CLASS_WINDOW: str
DEVICE_CLASSES: Any
DEVICE_CLASSES_SCHEMA: Any

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class BinarySensorEntityDescription(EntityDescription): ...

class BinarySensorEntity(Entity):
    entity_description: BinarySensorEntityDescription
    _attr_is_on: Union[bool, None]
    _attr_state: None
    @property
    def is_on(self) -> Union[bool, None]: ...
    @property
    def state(self) -> StateType: ...

class BinarySensorDevice(BinarySensorEntity):
    def __init_subclass__(cls, **kwargs: Any): ...



from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import SERVICE_CLOSE_COVER as SERVICE_CLOSE_COVER, SERVICE_CLOSE_COVER_TILT as SERVICE_CLOSE_COVER_TILT, SERVICE_OPEN_COVER as SERVICE_OPEN_COVER, SERVICE_OPEN_COVER_TILT as SERVICE_OPEN_COVER_TILT, SERVICE_SET_COVER_POSITION as SERVICE_SET_COVER_POSITION, SERVICE_SET_COVER_TILT_POSITION as SERVICE_SET_COVER_TILT_POSITION, SERVICE_STOP_COVER as SERVICE_STOP_COVER, SERVICE_STOP_COVER_TILT as SERVICE_STOP_COVER_TILT, SERVICE_TOGGLE as SERVICE_TOGGLE, SERVICE_TOGGLE_COVER_TILT as SERVICE_TOGGLE_COVER_TILT, STATE_CLOSED as STATE_CLOSED, STATE_CLOSING as STATE_CLOSING, STATE_OPEN as STATE_OPEN, STATE_OPENING as STATE_OPENING
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.config_validation import PLATFORM_SCHEMA as PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE as PLATFORM_SCHEMA_BASE
from homeassistant.helpers.entity import Entity as Entity, EntityDescription as EntityDescription
from homeassistant.helpers.entity_component import EntityComponent as EntityComponent
from homeassistant.loader import bind_hass as bind_hass
from typing import Any

_LOGGER: Any
DOMAIN: str
SCAN_INTERVAL: Any
ENTITY_ID_FORMAT: Any
DEVICE_CLASS_AWNING: str
DEVICE_CLASS_BLIND: str
DEVICE_CLASS_CURTAIN: str
DEVICE_CLASS_DAMPER: str
DEVICE_CLASS_DOOR: str
DEVICE_CLASS_GARAGE: str
DEVICE_CLASS_GATE: str
DEVICE_CLASS_SHADE: str
DEVICE_CLASS_SHUTTER: str
DEVICE_CLASS_WINDOW: str
DEVICE_CLASSES: Any
DEVICE_CLASSES_SCHEMA: Any
SUPPORT_OPEN: int
SUPPORT_CLOSE: int
SUPPORT_SET_POSITION: int
SUPPORT_STOP: int
SUPPORT_OPEN_TILT: int
SUPPORT_CLOSE_TILT: int
SUPPORT_STOP_TILT: int
SUPPORT_SET_TILT_POSITION: int
ATTR_CURRENT_POSITION: str
ATTR_CURRENT_TILT_POSITION: str
ATTR_POSITION: str
ATTR_TILT_POSITION: str

def is_closed(hass, entity_id): ...
async def async_setup(hass, config): ...
async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...

class CoverEntityDescription(EntityDescription): ...

class CoverEntity(Entity):
    entity_description: CoverEntityDescription
    _attr_current_cover_position: Union[int, None]
    _attr_current_cover_tilt_position: Union[int, None]
    _attr_is_closed: Union[bool, None]
    _attr_is_closing: Union[bool, None]
    _attr_is_opening: Union[bool, None]
    _attr_state: None
    @property
    def current_cover_position(self) -> Union[int, None]: ...
    @property
    def current_cover_tilt_position(self) -> Union[int, None]: ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def state_attributes(self): ...
    @property
    def supported_features(self) -> int: ...
    @property
    def is_opening(self) -> Union[bool, None]: ...
    @property
    def is_closing(self) -> Union[bool, None]: ...
    @property
    def is_closed(self) -> Union[bool, None]: ...
    def open_cover(self, **kwargs: Any) -> None: ...
    async def async_open_cover(self, **kwargs) -> None: ...
    def close_cover(self, **kwargs: Any) -> None: ...
    async def async_close_cover(self, **kwargs) -> None: ...
    def toggle(self, **kwargs: Any) -> None: ...
    async def async_toggle(self, **kwargs) -> None: ...
    def set_cover_position(self, **kwargs) -> None: ...
    async def async_set_cover_position(self, **kwargs) -> None: ...
    def stop_cover(self, **kwargs) -> None: ...
    async def async_stop_cover(self, **kwargs) -> None: ...
    def open_cover_tilt(self, **kwargs: Any) -> None: ...
    async def async_open_cover_tilt(self, **kwargs) -> None: ...
    def close_cover_tilt(self, **kwargs: Any) -> None: ...
    async def async_close_cover_tilt(self, **kwargs) -> None: ...
    def set_cover_tilt_position(self, **kwargs) -> None: ...
    async def async_set_cover_tilt_position(self, **kwargs) -> None: ...
    def stop_cover_tilt(self, **kwargs) -> None: ...
    async def async_stop_cover_tilt(self, **kwargs) -> None: ...
    def toggle_tilt(self, **kwargs: Any) -> None: ...
    async def async_toggle_tilt(self, **kwargs) -> None: ...

class CoverDevice(CoverEntity):
    def __init_subclass__(cls, **kwargs) -> None: ...



from . import DOMAIN as DOMAIN
from collections.abc import Iterable
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, SERVICE_LOCK as SERVICE_LOCK, SERVICE_UNLOCK as SERVICE_UNLOCK, STATE_LOCKED as STATE_LOCKED, STATE_LOCKING as STATE_LOCKING, STATE_UNLOCKED as STATE_UNLOCKED, STATE_UNLOCKING as STATE_UNLOCKING
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, State as State
from typing import Any

_LOGGER: Any
VALID_STATES: Any

async def _async_reproduce_state(hass: HomeAssistant, state: State, *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...
async def async_reproduce_states(hass: HomeAssistant, states: Iterable[State], *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...



from .const import CONF_RESPOND_TO_READ as CONF_RESPOND_TO_READ, CONF_STATE_ADDRESS as CONF_STATE_ADDRESS, DOMAIN as DOMAIN, KNX_ADDRESS as KNX_ADDRESS
from .knx_entity import KnxEntity as KnxEntity
from .schema import NumberSchema as NumberSchema
from homeassistant.components.number import NumberEntity as NumberEntity
from homeassistant.const import CONF_NAME as CONF_NAME, CONF_TYPE as CONF_TYPE, STATE_UNAVAILABLE as STATE_UNAVAILABLE, STATE_UNKNOWN as STATE_UNKNOWN
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.restore_state import RestoreEntity as RestoreEntity
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from typing import Any
from xknx import XKNX as XKNX
from xknx.devices import NumericValue

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...
def _create_numeric_value(xknx: XKNX, config: ConfigType) -> NumericValue: ...

class KNXNumber(KnxEntity, NumberEntity, RestoreEntity):
    _device: NumericValue
    _attr_max_value: Any
    _attr_min_value: Any
    _attr_step: Any
    _attr_unique_id: Any
    def __init__(self, xknx: XKNX, config: ConfigType) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    @property
    def value(self) -> float: ...
    async def async_set_value(self, value: float) -> None: ...



import voluptuous as vol
from . import commands as commands, connection as connection, const as const, decorators as decorators, http as http, messages as messages
from .connection import ActiveConnection as ActiveConnection
from .const import AsyncWebSocketCommandHandler as AsyncWebSocketCommandHandler, ERR_HOME_ASSISTANT_ERROR as ERR_HOME_ASSISTANT_ERROR, ERR_INVALID_FORMAT as ERR_INVALID_FORMAT, ERR_NOT_FOUND as ERR_NOT_FOUND, ERR_NOT_SUPPORTED as ERR_NOT_SUPPORTED, ERR_TEMPLATE_ERROR as ERR_TEMPLATE_ERROR, ERR_TIMEOUT as ERR_TIMEOUT, ERR_UNAUTHORIZED as ERR_UNAUTHORIZED, ERR_UNKNOWN_COMMAND as ERR_UNKNOWN_COMMAND, ERR_UNKNOWN_ERROR as ERR_UNKNOWN_ERROR, WebSocketCommandHandler as WebSocketCommandHandler
from .decorators import async_response as async_response, require_admin as require_admin, websocket_command as websocket_command, ws_require_user as ws_require_user
from .messages import BASE_COMMAND_MESSAGE_SCHEMA as BASE_COMMAND_MESSAGE_SCHEMA, error_message as error_message, event_message as event_message, result_message as result_message
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.loader import bind_hass as bind_hass
from typing import Any, Final

DOMAIN: Final[Any]
DEPENDENCIES: Final[tuple[str]]

def async_register_command(hass: HomeAssistant, command_or_handler: Union[str, const.WebSocketCommandHandler], handler: Union[const.WebSocketCommandHandler, None] = ..., schema: Union[vol.Schema, None] = ...) -> None: ...
async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...



from .const import DiscoveryInfo as DiscoveryInfo
from .helpers import on_unload as on_unload
from homeassistant.components import mysensors as mysensors
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity, DEVICE_CLASSES as DEVICE_CLASSES, DEVICE_CLASS_MOISTURE as DEVICE_CLASS_MOISTURE, DEVICE_CLASS_MOTION as DEVICE_CLASS_MOTION, DEVICE_CLASS_SAFETY as DEVICE_CLASS_SAFETY, DEVICE_CLASS_SOUND as DEVICE_CLASS_SOUND, DEVICE_CLASS_VIBRATION as DEVICE_CLASS_VIBRATION, DOMAIN as DOMAIN
from homeassistant.components.mysensors.const import MYSENSORS_DISCOVERY as MYSENSORS_DISCOVERY
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import STATE_ON as STATE_ON
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

SENSORS: Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class MySensorsBinarySensor(mysensors.device.MySensorsEntity, BinarySensorEntity):
    @property
    def is_on(self) -> bool: ...
    @property
    def device_class(self) -> Union[str, None]: ...



import voluptuous as vol
from . import DOMAIN as DOMAIN
from homeassistant.components.alarm_control_panel.const import SUPPORT_ALARM_ARM_AWAY as SUPPORT_ALARM_ARM_AWAY, SUPPORT_ALARM_ARM_HOME as SUPPORT_ALARM_ARM_HOME, SUPPORT_ALARM_ARM_NIGHT as SUPPORT_ALARM_ARM_NIGHT, SUPPORT_ALARM_ARM_VACATION as SUPPORT_ALARM_ARM_VACATION
from homeassistant.components.automation import AutomationActionType as AutomationActionType
from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA as DEVICE_TRIGGER_BASE_SCHEMA
from homeassistant.const import CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_FOR as CONF_FOR, CONF_PLATFORM as CONF_PLATFORM, CONF_TYPE as CONF_TYPE, STATE_ALARM_ARMED_AWAY as STATE_ALARM_ARMED_AWAY, STATE_ALARM_ARMED_HOME as STATE_ALARM_ARMED_HOME, STATE_ALARM_ARMED_NIGHT as STATE_ALARM_ARMED_NIGHT, STATE_ALARM_ARMED_VACATION as STATE_ALARM_ARMED_VACATION, STATE_ALARM_ARMING as STATE_ALARM_ARMING, STATE_ALARM_DISARMED as STATE_ALARM_DISARMED, STATE_ALARM_TRIGGERED as STATE_ALARM_TRIGGERED
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, HomeAssistant as HomeAssistant
from homeassistant.helpers import entity_registry as entity_registry
from homeassistant.helpers.entity import get_supported_features as get_supported_features
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any, Final

BASIC_TRIGGER_TYPES: Final[set[str]]
TRIGGER_TYPES: Final[set[str]]
TRIGGER_SCHEMA: Final[Any]

async def async_get_triggers(hass: HomeAssistant, device_id: str) -> list[dict[str, str]]: ...
async def async_get_trigger_capabilities(hass: HomeAssistant, config: ConfigType) -> dict[str, vol.Schema]: ...
async def async_attach_trigger(hass: HomeAssistant, config: ConfigType, action: AutomationActionType, automation_info: dict) -> CALLBACK_TYPE: ...



import pyatmo
from .const import ATTR_CAMERA_LIGHT_MODE as ATTR_CAMERA_LIGHT_MODE, ATTR_PERSON as ATTR_PERSON, ATTR_PERSONS as ATTR_PERSONS, ATTR_PSEUDO as ATTR_PSEUDO, CAMERA_LIGHT_MODES as CAMERA_LIGHT_MODES, DATA_CAMERAS as DATA_CAMERAS, DATA_EVENTS as DATA_EVENTS, DATA_HANDLER as DATA_HANDLER, DATA_PERSONS as DATA_PERSONS, DOMAIN as DOMAIN, EVENT_TYPE_LIGHT_MODE as EVENT_TYPE_LIGHT_MODE, EVENT_TYPE_OFF as EVENT_TYPE_OFF, EVENT_TYPE_ON as EVENT_TYPE_ON, MANUFACTURER as MANUFACTURER, MODELS as MODELS, SERVICE_SET_CAMERA_LIGHT as SERVICE_SET_CAMERA_LIGHT, SERVICE_SET_PERSONS_HOME as SERVICE_SET_PERSONS_HOME, SERVICE_SET_PERSON_AWAY as SERVICE_SET_PERSON_AWAY, SIGNAL_NAME as SIGNAL_NAME, WEBHOOK_LIGHT_MODE as WEBHOOK_LIGHT_MODE, WEBHOOK_NACAMERA_CONNECTION as WEBHOOK_NACAMERA_CONNECTION, WEBHOOK_PUSH_TYPE as WEBHOOK_PUSH_TYPE
from .data_handler import CAMERA_DATA_CLASS_NAME as CAMERA_DATA_CLASS_NAME, NetatmoDataHandler as NetatmoDataHandler
from .netatmo_entity_base import NetatmoBase as NetatmoBase
from homeassistant.components.camera import Camera as Camera, SUPPORT_STREAM as SUPPORT_STREAM
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import PlatformNotReady as PlatformNotReady
from homeassistant.helpers import entity_platform as entity_platform
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

_LOGGER: Any
DEFAULT_QUALITY: str

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class NetatmoCamera(NetatmoBase, Camera):
    _id: Any
    _home_id: Any
    _device_name: Any
    _attr_name: Any
    _model: Any
    _attr_unique_id: Any
    _quality: Any
    _vpnurl: Any
    _localurl: Any
    _status: Any
    _sd_status: Any
    _alim_status: Any
    _is_local: Any
    _light_state: Any
    def __init__(self, data_handler: NetatmoDataHandler, camera_id: str, camera_type: str, home_id: str, quality: str) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    is_streaming: bool
    def handle_event(self, event: dict) -> None: ...
    @property
    def _data(self) -> pyatmo.AsyncCameraData: ...
    async def async_camera_image(self) -> Union[bytes, None]: ...
    @property
    def available(self) -> bool: ...
    @property
    def supported_features(self) -> int: ...
    @property
    def brand(self) -> str: ...
    @property
    def motion_detection_enabled(self) -> bool: ...
    @property
    def is_on(self) -> bool: ...
    async def async_turn_off(self) -> None: ...
    async def async_turn_on(self) -> None: ...
    async def stream_source(self) -> str: ...
    @property
    def model(self) -> str: ...
    def async_update_callback(self) -> None: ...
    def process_events(self, events: dict) -> dict: ...
    async def _service_set_persons_home(self, **kwargs: Any) -> None: ...
    async def _service_set_person_away(self, **kwargs: Any) -> None: ...
    async def _service_set_camera_light(self, **kwargs: Any) -> None: ...



from . import ATTR_BRIGHTNESS_PCT as ATTR_BRIGHTNESS_PCT, ATTR_RGB_COLOR as ATTR_RGB_COLOR, ATTR_SUPPORTED_COLOR_MODES as ATTR_SUPPORTED_COLOR_MODES, DOMAIN as DOMAIN, SERVICE_TURN_ON as SERVICE_TURN_ON, brightness_supported as brightness_supported, color_supported as color_supported
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID
from homeassistant.core import HomeAssistant as HomeAssistant, State as State
from homeassistant.helpers import intent as intent
from typing import Any

INTENT_SET: str

async def async_setup_intents(hass: HomeAssistant) -> None: ...
def _test_supports_color(state: State) -> None: ...
def _test_supports_brightness(state: State) -> None: ...

class SetIntentHandler(intent.IntentHandler):
    intent_type: Any
    slot_schema: Any
    async def async_handle(self, intent_obj: intent.Intent) -> intent.IntentResponse: ...



from .const import ATTR_COUNTER as ATTR_COUNTER, ATTR_LAST_KNX_UPDATE as ATTR_LAST_KNX_UPDATE, ATTR_SOURCE as ATTR_SOURCE, DOMAIN as DOMAIN
from .knx_entity import KnxEntity as KnxEntity
from .schema import BinarySensorSchema as BinarySensorSchema
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity
from homeassistant.const import CONF_DEVICE_CLASS as CONF_DEVICE_CLASS, CONF_NAME as CONF_NAME
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from homeassistant.util import dt as dt
from typing import Any
from xknx import XKNX as XKNX
from xknx.devices import BinarySensor as XknxBinarySensor

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: AddEntitiesCallback, discovery_info: Union[DiscoveryInfoType, None] = ...) -> None: ...

class KNXBinarySensor(KnxEntity, BinarySensorEntity):
    _device: XknxBinarySensor
    _attr_device_class: Any
    _attr_force_update: Any
    _attr_unique_id: Any
    def __init__(self, xknx: XKNX, config: ConfigType) -> None: ...
    @property
    def is_on(self) -> bool: ...
    @property
    def extra_state_attributes(self) -> Union[dict[str, Any], None]: ...



from .const import DOMAIN as DOMAIN
from .devolo_multi_level_switch import DevoloMultiLevelSwitchDeviceEntity as DevoloMultiLevelSwitchDeviceEntity
from devolo_home_control_api.devices.zwave import Zwave as Zwave
from devolo_home_control_api.homecontrol import HomeControl as HomeControl
from homeassistant.components.light import ATTR_BRIGHTNESS as ATTR_BRIGHTNESS, LightEntity as LightEntity, SUPPORT_BRIGHTNESS as SUPPORT_BRIGHTNESS
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class DevoloLightDeviceEntity(DevoloMultiLevelSwitchDeviceEntity, LightEntity):
    _attr_supported_features: Any
    _binary_switch_property: Any
    def __init__(self, homecontrol: HomeControl, device_instance: Zwave, element_uid: str) -> None: ...
    @property
    def brightness(self) -> int: ...
    @property
    def is_on(self) -> bool: ...
    def turn_on(self, **kwargs: Any) -> None: ...
    def turn_off(self, **kwargs: Any) -> None: ...



from . import SynoApi as SynoApi, SynologyDSMBaseEntity as SynologyDSMBaseEntity
from .const import COORDINATOR_CAMERAS as COORDINATOR_CAMERAS, DOMAIN as DOMAIN, ENTITY_ENABLE as ENTITY_ENABLE, SYNO_API as SYNO_API
from homeassistant.components.camera import Camera as Camera, SUPPORT_STREAM as SUPPORT_STREAM
from homeassistant.components.sensor import ATTR_STATE_CLASS as ATTR_STATE_CLASS
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_DEVICE_CLASS as ATTR_DEVICE_CLASS, ATTR_ICON as ATTR_ICON, ATTR_NAME as ATTR_NAME, ATTR_UNIT_OF_MEASUREMENT as ATTR_UNIT_OF_MEASUREMENT
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator
from synology_dsm.api.surveillance_station import SynoCamera as SynoCamera
from typing import Any

_LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class SynoDSMCamera(SynologyDSMBaseEntity, Camera):
    coordinator: DataUpdateCoordinator[dict[str, dict[str, SynoCamera]]]
    _camera_id: Any
    def __init__(self, api: SynoApi, coordinator: DataUpdateCoordinator[dict[str, dict[str, SynoCamera]]], camera_id: str) -> None: ...
    @property
    def camera_data(self) -> SynoCamera: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    @property
    def available(self) -> bool: ...
    @property
    def supported_features(self) -> int: ...
    @property
    def is_recording(self) -> bool: ...
    @property
    def motion_detection_enabled(self) -> bool: ...
    def camera_image(self) -> Union[bytes, None]: ...
    async def stream_source(self) -> Union[str, None]: ...
    def enable_motion_detection(self) -> None: ...
    def disable_motion_detection(self) -> None: ...



from typing import Final

CONF_REGION: Final[str]
CONF_ACCESS_KEY_ID: Final[str]
CONF_SECRET_ACCESS_KEY: Final[str]
DEFAULT_REGION: Final[str]
SUPPORTED_REGIONS: Final[list[str]]
CONF_ENGINE: Final[str]
CONF_VOICE: Final[str]
CONF_OUTPUT_FORMAT: Final[str]
CONF_SAMPLE_RATE: Final[str]
CONF_TEXT_TYPE: Final[str]
SUPPORTED_VOICES: Final[list[str]]
SUPPORTED_OUTPUT_FORMATS: Final[list[str]]
SUPPORTED_ENGINES: Final[list[str]]
SUPPORTED_SAMPLE_RATES: Final[list[str]]
SUPPORTED_SAMPLE_RATES_MAP: Final[dict[str, list[str]]]
SUPPORTED_TEXT_TYPES: Final[list[str]]
CONTENT_TYPE_EXTENSIONS: Final[dict[str, str]]
DEFAULT_ENGINE: Final[str]
DEFAULT_VOICE: Final[str]
DEFAULT_OUTPUT_FORMAT: Final[str]
DEFAULT_TEXT_TYPE: Final[str]
DEFAULT_SAMPLE_RATES: Final[dict[str, str]]
AWS_CONF_CONNECT_TIMEOUT: Final[int]
AWS_CONF_READ_TIMEOUT: Final[int]
AWS_CONF_MAX_POOL_CONNECTIONS: Final[int]



from homeassistant.components.cover import SUPPORT_CLOSE as SUPPORT_CLOSE, SUPPORT_OPEN as SUPPORT_OPEN
from homeassistant.const import STATE_CLOSED as STATE_CLOSED, STATE_CLOSING as STATE_CLOSING, STATE_OPEN as STATE_OPEN, STATE_OPENING as STATE_OPENING
from typing import Any, Final

NOTIFICATION_ID: Final[str]
NOTIFICATION_TITLE: Final[str]
STATES_MAP: Final[dict[str, str]]
SUPPORTED_FEATURES: Final[Any]



import asyncio
from abc import ABC
from collections.abc import Awaitable, Iterable, Mapping, MutableMapping
from datetime import datetime, timedelta
from homeassistant.config import DATA_CUSTOMIZE as DATA_CUSTOMIZE
from homeassistant.const import ATTR_ASSUMED_STATE as ATTR_ASSUMED_STATE, ATTR_DEVICE_CLASS as ATTR_DEVICE_CLASS, ATTR_ENTITY_PICTURE as ATTR_ENTITY_PICTURE, ATTR_FRIENDLY_NAME as ATTR_FRIENDLY_NAME, ATTR_ICON as ATTR_ICON, ATTR_SUPPORTED_FEATURES as ATTR_SUPPORTED_FEATURES, ATTR_UNIT_OF_MEASUREMENT as ATTR_UNIT_OF_MEASUREMENT, DEVICE_DEFAULT_NAME as DEVICE_DEFAULT_NAME, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON, STATE_UNAVAILABLE as STATE_UNAVAILABLE, STATE_UNKNOWN as STATE_UNKNOWN, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, Context as Context, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError, NoEntitySpecifiedError as NoEntitySpecifiedError
from homeassistant.helpers.entity_platform import EntityPlatform as EntityPlatform
from homeassistant.helpers.entity_registry import RegistryEntry as RegistryEntry
from homeassistant.helpers.event import Event as Event, async_track_entity_registry_updated_event as async_track_entity_registry_updated_event
from homeassistant.helpers.typing import StateType as StateType
from homeassistant.loader import bind_hass as bind_hass
from homeassistant.util import ensure_unique_string as ensure_unique_string, slugify as slugify
from typing import Any, TypedDict

_LOGGER: Any
SLOW_UPDATE_WARNING: int
DATA_ENTITY_SOURCE: str
SOURCE_CONFIG_ENTRY: str
SOURCE_PLATFORM_CONFIG: str
FLOAT_PRECISION: Any

def entity_sources(hass: HomeAssistant) -> dict[str, dict[str, str]]: ...
def generate_entity_id(entity_id_format: str, name: Union[str, None], current_ids: Union[list[str], None] = ..., hass: Union[HomeAssistant, None] = ...) -> str: ...
def async_generate_entity_id(entity_id_format: str, name: Union[str, None], current_ids: Union[Iterable[str], None] = ..., hass: Union[HomeAssistant, None] = ...) -> str: ...
def get_capability(hass: HomeAssistant, entity_id: str, capability: str) -> Union[Any, None]: ...
def get_device_class(hass: HomeAssistant, entity_id: str) -> Union[str, None]: ...
def get_supported_features(hass: HomeAssistant, entity_id: str) -> int: ...
def get_unit_of_measurement(hass: HomeAssistant, entity_id: str) -> Union[str, None]: ...

class DeviceInfo(TypedDict):
    name: str
    connections: set[tuple[str, str]]
    identifiers: set[tuple[str, str]]
    manufacturer: str
    model: str
    suggested_area: str
    sw_version: str
    via_device: tuple[str, str]
    entry_type: Union[str, None]
    default_name: str
    default_manufacturer: str
    default_model: str

class EntityDescription:
    key: str
    device_class: Union[str, None]
    entity_registry_enabled_default: bool
    force_update: bool
    icon: Union[str, None]
    name: Union[str, None]
    unit_of_measurement: Union[str, None]

class Entity(ABC):
    entity_id: str
    hass: HomeAssistant
    platform: Union[EntityPlatform, None]
    entity_description: EntityDescription
    _slow_reported: bool
    _disabled_reported: bool
    _update_staged: bool
    parallel_updates: Union[asyncio.Semaphore, None]
    registry_entry: Union[RegistryEntry, None]
    _on_remove: Union[list[CALLBACK_TYPE], None]
    _context: Union[Context, None]
    _context_set: Union[datetime, None]
    _added: bool
    _attr_assumed_state: bool
    _attr_available: bool
    _attr_context_recent_time: timedelta
    _attr_device_class: Union[str, None]
    _attr_device_info: Union[DeviceInfo, None]
    _attr_entity_picture: Union[str, None]
    _attr_entity_registry_enabled_default: bool
    _attr_extra_state_attributes: MutableMapping[str, Any]
    _attr_force_update: bool
    _attr_icon: Union[str, None]
    _attr_name: Union[str, None]
    _attr_should_poll: bool
    _attr_state: StateType
    _attr_supported_features: Union[int, None]
    _attr_unique_id: Union[str, None]
    _attr_unit_of_measurement: Union[str, None]
    @property
    def should_poll(self) -> bool: ...
    @property
    def unique_id(self) -> Union[str, None]: ...
    @property
    def name(self) -> Union[str, None]: ...
    @property
    def state(self) -> StateType: ...
    @property
    def capability_attributes(self) -> Union[Mapping[str, Any], None]: ...
    @property
    def state_attributes(self) -> Union[dict[str, Any], None]: ...
    @property
    def device_state_attributes(self) -> Union[Mapping[str, Any], None]: ...
    @property
    def extra_state_attributes(self) -> Union[Mapping[str, Any], None]: ...
    @property
    def device_info(self) -> Union[DeviceInfo, None]: ...
    @property
    def device_class(self) -> Union[str, None]: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...
    @property
    def icon(self) -> Union[str, None]: ...
    @property
    def entity_picture(self) -> Union[str, None]: ...
    @property
    def available(self) -> bool: ...
    @property
    def assumed_state(self) -> bool: ...
    @property
    def force_update(self) -> bool: ...
    @property
    def supported_features(self) -> Union[int, None]: ...
    @property
    def context_recent_time(self) -> timedelta: ...
    @property
    def entity_registry_enabled_default(self) -> bool: ...
    @property
    def enabled(self) -> bool: ...
    def async_set_context(self, context: Context) -> None: ...
    async def async_update_ha_state(self, force_refresh: bool = ...) -> None: ...
    def async_write_ha_state(self) -> None: ...
    def _stringify_state(self) -> str: ...
    def _async_write_ha_state(self) -> None: ...
    def schedule_update_ha_state(self, force_refresh: bool = ...) -> None: ...
    def async_schedule_update_ha_state(self, force_refresh: bool = ...) -> None: ...
    async def async_device_update(self, warning: bool = ...) -> None: ...
    def async_on_remove(self, func: CALLBACK_TYPE) -> None: ...
    async def async_removed_from_registry(self) -> None: ...
    def add_to_platform_start(self, hass: HomeAssistant, platform: EntityPlatform, parallel_updates: Union[asyncio.Semaphore, None]) -> None: ...
    def add_to_platform_abort(self) -> None: ...
    async def add_to_platform_finish(self) -> None: ...
    async def async_remove(self, *, force_remove: bool = ...) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    async def async_internal_added_to_hass(self) -> None: ...
    async def async_internal_will_remove_from_hass(self) -> None: ...
    async def _async_registry_updated(self, event: Event) -> None: ...
    def __eq__(self, other: Any) -> bool: ...
    def __repr__(self) -> str: ...
    async def async_request_call(self, coro: Awaitable) -> None: ...

class ToggleEntityDescription(EntityDescription): ...

class ToggleEntity(Entity):
    entity_description: ToggleEntityDescription
    _attr_is_on: bool
    _attr_state: None
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def is_on(self) -> bool: ...
    def turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    def turn_off(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...
    def toggle(self, **kwargs: Any) -> None: ...
    async def async_toggle(self, **kwargs: Any) -> None: ...



from .const import CONF_DIM_MODE as CONF_DIM_MODE, CONF_SK_NUM_TRIES as CONF_SK_NUM_TRIES, DOMAIN as DOMAIN
from homeassistant import config_entries as config_entries
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_IP_ADDRESS as CONF_IP_ADDRESS, CONF_PASSWORD as CONF_PASSWORD, CONF_PORT as CONF_PORT, CONF_USERNAME as CONF_USERNAME
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

_LOGGER: Any

def get_config_entry(hass: HomeAssistant, data: ConfigType) -> Union[config_entries.ConfigEntry, None]: ...
async def validate_connection(host_name: str, data: ConfigType) -> ConfigType: ...

class LcnFlowHandler(config_entries.ConfigFlow):
    VERSION: int
    async def async_step_import(self, data: ConfigType) -> FlowResult: ...



import voluptuous as vol
from collections.abc import Iterable
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, ATTR_SUPPORTED_FEATURES as ATTR_SUPPORTED_FEATURES
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, State as State, T as T, callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.loader import bind_hass as bind_hass
from typing import Any, Callable, Dict

_LOGGER: Any
_SlotsType = Dict[str, Any]
INTENT_TURN_OFF: str
INTENT_TURN_ON: str
INTENT_TOGGLE: str
SLOT_SCHEMA: Any
DATA_KEY: str
SPEECH_TYPE_PLAIN: str
SPEECH_TYPE_SSML: str

def async_register(hass: HomeAssistant, handler: IntentHandler) -> None: ...
async def async_handle(hass: HomeAssistant, platform: str, intent_type: str, slots: Union[_SlotsType, None] = ..., text_input: Union[str, None] = ..., context: Union[Context, None] = ...) -> IntentResponse: ...

class IntentError(HomeAssistantError): ...
class UnknownIntent(IntentError): ...
class InvalidSlotInfo(IntentError): ...
class IntentHandleError(IntentError): ...
class IntentUnexpectedError(IntentError): ...

def async_match_state(hass: HomeAssistant, name: str, states: Union[Iterable[State], None] = ...) -> State: ...
def async_test_feature(state: State, feature: int, feature_name: str) -> None: ...

class IntentHandler:
    intent_type: Union[str, None]
    slot_schema: Union[vol.Schema, None]
    _slot_schema: Union[vol.Schema, None]
    platforms: Union[Iterable[str], None]
    def async_can_handle(self, intent_obj: Intent) -> bool: ...
    def async_validate_slots(self, slots: _SlotsType) -> _SlotsType: ...
    async def async_handle(self, intent_obj: Intent) -> IntentResponse: ...
    def __repr__(self) -> str: ...

def _fuzzymatch(name: str, items: Iterable[T], key: Callable[[T], str]) -> Union[T, None]: ...

class ServiceIntentHandler(IntentHandler):
    slot_schema: Any
    intent_type: Any
    domain: Any
    service: Any
    speech: Any
    def __init__(self, intent_type: str, domain: str, service: str, speech: str) -> None: ...
    async def async_handle(self, intent_obj: Intent) -> IntentResponse: ...

class Intent:
    __slots__: Any
    hass: Any
    platform: Any
    intent_type: Any
    slots: Any
    text_input: Any
    context: Any
    def __init__(self, hass: HomeAssistant, platform: str, intent_type: str, slots: _SlotsType, text_input: Union[str, None], context: Context) -> None: ...
    def create_response(self) -> IntentResponse: ...

class IntentResponse:
    intent: Any
    speech: Any
    card: Any
    def __init__(self, intent: Union[Intent, None] = ...) -> None: ...
    def async_set_speech(self, speech: str, speech_type: str = ..., extra_data: Union[Any, None] = ...) -> None: ...
    def async_set_card(self, title: str, content: str, card_type: str = ...) -> None: ...
    def as_dict(self) -> dict[str, dict[str, dict[str, Any]]]: ...



from . import RitualsDataUpdateCoordinator as RitualsDataUpdateCoordinator
from .const import COORDINATORS as COORDINATORS, DEVICES as DEVICES, DOMAIN as DOMAIN
from .entity import DiffuserEntity as DiffuserEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_SIGNAL_STRENGTH as DEVICE_CLASS_SIGNAL_STRENGTH, PERCENTAGE as PERCENTAGE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from pyrituals import Diffuser as Diffuser
from typing import Any

BATTERY_SUFFIX: str
PERFUME_SUFFIX: str
FILL_SUFFIX: str
WIFI_SUFFIX: str

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class DiffuserPerfumeSensor(DiffuserEntity):
    def __init__(self, diffuser: Diffuser, coordinator: RitualsDataUpdateCoordinator) -> None: ...
    @property
    def icon(self) -> str: ...
    @property
    def state(self) -> str: ...

class DiffuserFillSensor(DiffuserEntity):
    def __init__(self, diffuser: Diffuser, coordinator: RitualsDataUpdateCoordinator) -> None: ...
    @property
    def icon(self) -> str: ...
    @property
    def state(self) -> str: ...

class DiffuserBatterySensor(DiffuserEntity):
    _attr_device_class: Any
    _attr_unit_of_measurement: Any
    def __init__(self, diffuser: Diffuser, coordinator: RitualsDataUpdateCoordinator) -> None: ...
    @property
    def state(self) -> int: ...

class DiffuserWifiSensor(DiffuserEntity):
    _attr_device_class: Any
    _attr_unit_of_measurement: Any
    def __init__(self, diffuser: Diffuser, coordinator: RitualsDataUpdateCoordinator) -> None: ...
    @property
    def state(self) -> int: ...



from . import DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_BATTERY_CHARGING as DEVICE_CLASS_BATTERY_CHARGING, DEVICE_CLASS_COLD as DEVICE_CLASS_COLD, DEVICE_CLASS_CONNECTIVITY as DEVICE_CLASS_CONNECTIVITY, DEVICE_CLASS_DOOR as DEVICE_CLASS_DOOR, DEVICE_CLASS_GARAGE_DOOR as DEVICE_CLASS_GARAGE_DOOR, DEVICE_CLASS_GAS as DEVICE_CLASS_GAS, DEVICE_CLASS_HEAT as DEVICE_CLASS_HEAT, DEVICE_CLASS_LIGHT as DEVICE_CLASS_LIGHT, DEVICE_CLASS_LOCK as DEVICE_CLASS_LOCK, DEVICE_CLASS_MOISTURE as DEVICE_CLASS_MOISTURE, DEVICE_CLASS_MOTION as DEVICE_CLASS_MOTION, DEVICE_CLASS_MOVING as DEVICE_CLASS_MOVING, DEVICE_CLASS_OCCUPANCY as DEVICE_CLASS_OCCUPANCY, DEVICE_CLASS_OPENING as DEVICE_CLASS_OPENING, DEVICE_CLASS_PLUG as DEVICE_CLASS_PLUG, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, DEVICE_CLASS_PRESENCE as DEVICE_CLASS_PRESENCE, DEVICE_CLASS_PROBLEM as DEVICE_CLASS_PROBLEM, DEVICE_CLASS_SAFETY as DEVICE_CLASS_SAFETY, DEVICE_CLASS_SMOKE as DEVICE_CLASS_SMOKE, DEVICE_CLASS_SOUND as DEVICE_CLASS_SOUND, DEVICE_CLASS_VIBRATION as DEVICE_CLASS_VIBRATION, DEVICE_CLASS_WINDOW as DEVICE_CLASS_WINDOW, DOMAIN as DOMAIN
from homeassistant.components.device_automation.const import CONF_IS_OFF as CONF_IS_OFF, CONF_IS_ON as CONF_IS_ON
from homeassistant.const import CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_FOR as CONF_FOR, CONF_TYPE as CONF_TYPE
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers import condition as condition
from homeassistant.helpers.entity import get_device_class as get_device_class
from homeassistant.helpers.entity_registry import async_entries_for_device as async_entries_for_device, async_get_registry as async_get_registry
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

DEVICE_CLASS_NONE: str
CONF_IS_BAT_LOW: str
CONF_IS_NOT_BAT_LOW: str
CONF_IS_CHARGING: str
CONF_IS_NOT_CHARGING: str
CONF_IS_COLD: str
CONF_IS_NOT_COLD: str
CONF_IS_CONNECTED: str
CONF_IS_NOT_CONNECTED: str
CONF_IS_GAS: str
CONF_IS_NO_GAS: str
CONF_IS_HOT: str
CONF_IS_NOT_HOT: str
CONF_IS_LIGHT: str
CONF_IS_NO_LIGHT: str
CONF_IS_LOCKED: str
CONF_IS_NOT_LOCKED: str
CONF_IS_MOIST: str
CONF_IS_NOT_MOIST: str
CONF_IS_MOTION: str
CONF_IS_NO_MOTION: str
CONF_IS_MOVING: str
CONF_IS_NOT_MOVING: str
CONF_IS_OCCUPIED: str
CONF_IS_NOT_OCCUPIED: str
CONF_IS_PLUGGED_IN: str
CONF_IS_NOT_PLUGGED_IN: str
CONF_IS_POWERED: str
CONF_IS_NOT_POWERED: str
CONF_IS_PRESENT: str
CONF_IS_NOT_PRESENT: str
CONF_IS_PROBLEM: str
CONF_IS_NO_PROBLEM: str
CONF_IS_UNSAFE: str
CONF_IS_NOT_UNSAFE: str
CONF_IS_SMOKE: str
CONF_IS_NO_SMOKE: str
CONF_IS_SOUND: str
CONF_IS_NO_SOUND: str
CONF_IS_VIBRATION: str
CONF_IS_NO_VIBRATION: str
CONF_IS_OPEN: str
CONF_IS_NOT_OPEN: str
IS_ON: Any
IS_OFF: Any
ENTITY_CONDITIONS: Any
CONDITION_SCHEMA: Any

async def async_get_conditions(hass: HomeAssistant, device_id: str) -> list[dict[str, str]]: ...
def async_condition_from_config(config: ConfigType, config_validation: bool) -> condition.ConditionCheckerType: ...
async def async_get_condition_capabilities(hass: HomeAssistant, config: dict) -> dict: ...



from .const import DOMAIN as DOMAIN
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.discovery import async_load_platform as async_load_platform
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

CONFIG_SCHEMA: Any

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...



from typing import TypedDict

class EntityInfo(TypedDict):
    name: str
    entity_id: str
    unit_of_measurement: Union[str, None]
    device_class: Union[str, None]
    state_class: Union[str, None]

class ClimateExtraAttributes(TypedDict):
    battery_low: bool
    device_locked: bool
    locked: bool
    battery_level: int
    holiday_mode: bool
    summer_mode: bool
    window_open: bool

class SensorExtraAttributes(TypedDict):
    device_locked: bool
    locked: bool

class SwitchExtraAttributes(TypedDict):
    device_locked: bool
    locked: bool
    total_consumption: str
    total_consumption_unit: str
    temperature: str
    temperature_unit: str



from homeassistant.const import DEGREE as DEGREE, ELECTRIC_POTENTIAL_VOLT as ELECTRIC_POTENTIAL_VOLT, PERCENTAGE as PERCENTAGE, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT, TEMP_KELVIN as TEMP_KELVIN
from typing import Any

PLATFORMS: Any
DOMAIN: str
DATA_LCN: str
DEFAULT_NAME: str
CONNECTION: str
CONF_HARDWARE_SERIAL: str
CONF_SOFTWARE_SERIAL: str
CONF_HARDWARE_TYPE: str
CONF_RESOURCE: str
CONF_DOMAIN_DATA: str
CONF_CONNECTIONS: str
CONF_SK_NUM_TRIES: str
CONF_OUTPUT: str
CONF_DIM_MODE: str
CONF_DIMMABLE: str
CONF_TRANSITION: str
CONF_MOTOR: str
CONF_LOCKABLE: str
CONF_VARIABLE: str
CONF_VALUE: str
CONF_RELVARREF: str
CONF_SETPOINT: str
CONF_LED: str
CONF_KEYS: str
CONF_TIME: str
CONF_TIME_UNIT: str
CONF_TABLE: str
CONF_ROW: str
CONF_TEXT: str
CONF_PCK: str
CONF_CLIMATES: str
CONF_MAX_TEMP: str
CONF_MIN_TEMP: str
CONF_SCENES: str
CONF_REGISTER: str
CONF_OUTPUTS: str
CONF_REVERSE_TIME: str
DIM_MODES: Any
OUTPUT_PORTS: Any
RELAY_PORTS: Any
MOTOR_PORTS: Any
LED_PORTS: Any
LED_STATUS: Any
LOGICOP_PORTS: Any
BINSENSOR_PORTS: Any
KEYS: Any
VARIABLES: Any
SETPOINTS: Any
THRESHOLDS: Any
S0_INPUTS: Any
VAR_UNITS: Any
RELVARREF: Any
SENDKEYCOMMANDS: Any
TIME_UNITS: Any
MOTOR_REVERSE_TIME: Any



from .typing import ConfigType as ConfigType
from collections.abc import Iterable, Sequence
from homeassistant.const import CONF_PLATFORM as CONF_PLATFORM
from typing import Any

def config_per_platform(config: ConfigType, domain: str) -> Iterable[tuple[Any, Any]]: ...
def extract_domain_configs(config: ConfigType, domain: str) -> Sequence[str]: ...



from homeassistant.helpers.template import Template as Template
from typing import TypedDict

class TcpSensorConfig(TypedDict):
    name: str
    host: str
    port: str
    timeout: int
    payload: str
    unit_of_measurement: Union[str, None]
    value_template: Union[Template, None]
    value_on: Union[str, None]
    buffer_size: int
    ssl: bool
    verify_ssl: bool
